import typing

import android.accounts
import android.content.pm
import android.content.res
import android.database
import android.database.sqlite
import android.graphics
import android.graphics.drawable
import android.net
import android.os
import android.text
import android.util
import android.view
import android.view.textclassifier
import java
import java.chaquopy
import java.io
import java.lang
import java.util
import java.util.concurrent
import java.util.function
import org.xmlpull.v1

class AbstractThreadedSyncAdapter(java.lang.Object):
    LOG_SYNC_DETAILS: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, context: Context, autoInitialize: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, context: Context, autoInitialize: bool | java.jboolean | java.lang.Boolean, allowParallelSyncs: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def getContext(self) -> Context: ...
    def getSyncAdapterBinder(self) -> android.os.IBinder: ...
    def onPerformSync(self, arg1: android.accounts.Account, arg2: android.os.Bundle, arg3: str | java.lang.String, arg4: ContentProviderClient, arg5: SyncResult, /) -> None: ...
    def onSecurityException(self, account: android.accounts.Account, extras: android.os.Bundle, authority: str | java.lang.String, syncResult: SyncResult, /) -> None: ...
    @typing.overload
    def onSyncCanceled(self) -> None: ...
    @typing.overload
    def onSyncCanceled(self, thread: java.lang.Thread, /) -> None: ...
    def onUnsyncableAccount(self) -> bool: ...

class ActivityNotFoundException(java.lang.RuntimeException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str | java.lang.String, /) -> None: ...

class AsyncQueryHandler(android.os.Handler):
    def __init__(self, cr: ContentResolver, /) -> None: ...
    def cancelOperation(self, token: int | java.jint | java.lang.Integer, /) -> None: ...
    def createHandler(self, looper: android.os.Looper, /) -> android.os.Handler: ...
    def handleMessage(self, msg: android.os.Message, /) -> None: ...
    def onDeleteComplete(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, result: int | java.jint | java.lang.Integer, /) -> None: ...
    def onInsertComplete(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, uri: android.net.Uri, /) -> None: ...
    def onQueryComplete(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, cursor: android.database.Cursor, /) -> None: ...
    def onUpdateComplete(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, result: int | java.jint | java.lang.Integer, /) -> None: ...
    def startDelete(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, uri: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def startInsert(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, uri: android.net.Uri, initialValues: ContentValues, /) -> None: ...
    def startQuery(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], orderBy: str | java.lang.String, /) -> None: ...
    def startUpdate(self, token: int | java.jint | java.lang.Integer, cookie: java.lang.Object | int | bool | float | str, uri: android.net.Uri, values: ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...

    class WorkerHandler(android.os.Handler):
        def __init__(self, this_0: AsyncQueryHandler, looper: android.os.Looper, /) -> None: ...
        def handleMessage(self, msg: android.os.Message, /) -> None: ...

    class WorkerArgs(java.lang.Object):
        cookie: java.lang.Object = ...
        handler: android.os.Handler = ...
        orderBy: str = ...
        projection: java.chaquopy.JavaArray[java.lang.String] = ...
        result: java.lang.Object = ...
        selection: str = ...
        selectionArgs: java.chaquopy.JavaArray[java.lang.String] = ...
        uri: android.net.Uri = ...
        values: ContentValues = ...
        def __init__(self) -> None: ...

_AsyncTaskLoader__D = typing.TypeVar('_AsyncTaskLoader__D')  # <D>
class AsyncTaskLoader(Loader[_AsyncTaskLoader__D], typing.Generic[_AsyncTaskLoader__D]):
    def __init__(self, context: Context, /) -> None: ...
    def cancelLoadInBackground(self) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def isLoadInBackgroundCanceled(self) -> bool: ...
    def loadInBackground(self) -> _AsyncTaskLoader__D: ...
    def onCancelLoad(self) -> bool: ...
    def onCanceled(self, data: _AsyncTaskLoader__D, /) -> None: ...
    def onForceLoad(self) -> None: ...
    def onLoadInBackground(self) -> _AsyncTaskLoader__D: ...
    def setUpdateThrottle(self, delayMS: int | java.jlong | java.lang.Long, /) -> None: ...

class AttributionSource(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AttributionSource]] = ...
    def checkCallingUid(self) -> bool: ...
    def describeContents(self) -> int: ...
    def enforceCallingUid(self) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAttributionTag(self) -> str | None: ...
    def getDeviceId(self) -> int: ...
    def getNext(self) -> AttributionSource | None: ...
    def getPackageName(self) -> str | None: ...
    def getPid(self) -> int: ...
    def getUid(self) -> int: ...
    def hashCode(self) -> int: ...
    def isTrusted(self, context: Context, /) -> bool: ...
    @staticmethod
    def myAttributionSource() -> AttributionSource: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self, uid: int | java.jint | java.lang.Integer, /) -> None: ...
        @typing.overload
        def __init__(self, current: AttributionSource, /) -> None: ...
        def build(self) -> AttributionSource: ...
        def setAttributionTag(self, value: str | java.lang.String, /) -> AttributionSource.Builder: ...
        def setDeviceId(self, deviceId: int | java.jint | java.lang.Integer, /) -> AttributionSource.Builder: ...
        def setNext(self, value: AttributionSource, /) -> AttributionSource.Builder: ...
        def setPackageName(self, value: str | java.lang.String, /) -> AttributionSource.Builder: ...
        def setPid(self, value: int | java.jint | java.lang.Integer, /) -> AttributionSource.Builder: ...

class BroadcastReceiver(java.lang.Object):
    def __init__(self) -> None: ...
    def abortBroadcast(self) -> None: ...
    def clearAbortBroadcast(self) -> None: ...
    def getAbortBroadcast(self) -> bool: ...
    def getDebugUnregister(self) -> bool: ...
    def getResultCode(self) -> int: ...
    def getResultData(self) -> str | None: ...
    def getResultExtras(self, makeMap: bool | java.jboolean | java.lang.Boolean, /) -> android.os.Bundle: ...
    def getSentFromPackage(self) -> str | None: ...
    def getSentFromUid(self) -> int: ...
    def goAsync(self) -> BroadcastReceiver.PendingResult: ...
    def isInitialStickyBroadcast(self) -> bool: ...
    def isOrderedBroadcast(self) -> bool: ...
    def onReceive(self, arg1: Context, arg2: Intent, /) -> None: ...
    def peekService(self, myContext: Context, service: Intent, /) -> android.os.IBinder: ...
    def setDebugUnregister(self, debug: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOrderedHint(self, isOrdered: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setResult(self, code: int | java.jint | java.lang.Integer, data: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
    def setResultCode(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
    def setResultData(self, data: str | java.lang.String, /) -> None: ...
    def setResultExtras(self, extras: android.os.Bundle, /) -> None: ...

    class PendingResult(java.lang.Object):
        def abortBroadcast(self) -> None: ...
        def clearAbortBroadcast(self) -> None: ...
        def finish(self) -> None: ...
        def getAbortBroadcast(self) -> bool: ...
        def getResultCode(self) -> int: ...
        def getResultData(self) -> str: ...
        def getResultExtras(self, makeMap: bool | java.jboolean | java.lang.Boolean, /) -> android.os.Bundle: ...
        def setResult(self, code: int | java.jint | java.lang.Integer, data: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
        def setResultCode(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
        def setResultData(self, data: str | java.lang.String, /) -> None: ...
        def setResultExtras(self, extras: android.os.Bundle, /) -> None: ...

class ClipData(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ClipData]] = ...
    @typing.overload
    def __init__(self, other: ClipData, /) -> None: ...
    @typing.overload
    def __init__(self, description: ClipDescription, item: ClipData.Item, /) -> None: ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, mimeTypes: java.chaquopy.JavaArray[java.lang.String], item: ClipData.Item, /) -> None: ...
    @typing.overload
    def addItem(self, item: ClipData.Item, /) -> None: ...
    @typing.overload
    def addItem(self, resolver: ContentResolver, item: ClipData.Item, /) -> None: ...
    def describeContents(self) -> int: ...
    def getDescription(self) -> ClipDescription: ...
    def getItemAt(self, index: int | java.jint | java.lang.Integer, /) -> ClipData.Item: ...
    def getItemCount(self) -> int: ...
    @staticmethod
    def newHtmlText(label: java.lang.CharSequence, text: java.lang.CharSequence, htmlText: str | java.lang.String, /) -> ClipData: ...
    @staticmethod
    def newIntent(label: java.lang.CharSequence, intent: Intent, /) -> ClipData: ...
    @staticmethod
    def newPlainText(label: java.lang.CharSequence, text: java.lang.CharSequence, /) -> ClipData: ...
    @staticmethod
    def newRawUri(label: java.lang.CharSequence, uri: android.net.Uri, /) -> ClipData: ...
    @staticmethod
    def newUri(resolver: ContentResolver, label: java.lang.CharSequence, uri: android.net.Uri, /) -> ClipData: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Item(java.lang.Object):
        @typing.overload
        def __init__(self, intent: Intent, /) -> None: ...
        @typing.overload
        def __init__(self, uri: android.net.Uri, /) -> None: ...
        @typing.overload
        def __init__(self, text: java.lang.CharSequence, /) -> None: ...
        @typing.overload
        def __init__(self, text: java.lang.CharSequence, htmlText: str | java.lang.String, /) -> None: ...
        @typing.overload
        def __init__(self, text: java.lang.CharSequence, intent: Intent, uri: android.net.Uri, /) -> None: ...
        @typing.overload
        def __init__(self, text: java.lang.CharSequence, htmlText: str | java.lang.String, intent: Intent, uri: android.net.Uri, /) -> None: ...
        def coerceToHtmlText(self, context: Context, /) -> str: ...
        def coerceToStyledText(self, context: Context, /) -> java.lang.CharSequence: ...
        def coerceToText(self, context: Context, /) -> java.lang.CharSequence: ...
        def getHtmlText(self) -> str: ...
        def getIntent(self) -> Intent: ...
        def getIntentSender(self) -> IntentSender: ...
        def getText(self) -> java.lang.CharSequence: ...
        def getTextLinks(self) -> android.view.textclassifier.TextLinks: ...
        def getUri(self) -> android.net.Uri: ...
        def toString(self) -> str: ...

        class Builder(java.lang.Object):
            def __init__(self) -> None: ...
            def build(self) -> ClipData.Item: ...
            def setHtmlText(self, htmlText: str | java.lang.String, /) -> ClipData.Item.Builder: ...
            def setIntent(self, intent: Intent, /) -> ClipData.Item.Builder: ...
            def setIntentSender(self, intentSender: IntentSender, /) -> ClipData.Item.Builder: ...
            def setText(self, text: java.lang.CharSequence, /) -> ClipData.Item.Builder: ...
            def setUri(self, uri: android.net.Uri, /) -> ClipData.Item.Builder: ...

class ClipDescription(android.os.Parcelable):
    CLASSIFICATION_COMPLETE: typing.ClassVar[int] = ...
    CLASSIFICATION_NOT_COMPLETE: typing.ClassVar[int] = ...
    CLASSIFICATION_NOT_PERFORMED: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ClipDescription]] = ...
    EXTRA_IS_REMOTE_DEVICE: typing.ClassVar[str] = ...
    EXTRA_IS_SENSITIVE: typing.ClassVar[str] = ...
    MIMETYPE_TEXT_HTML: typing.ClassVar[str] = ...
    MIMETYPE_TEXT_INTENT: typing.ClassVar[str] = ...
    MIMETYPE_TEXT_PLAIN: typing.ClassVar[str] = ...
    MIMETYPE_TEXT_URILIST: typing.ClassVar[str] = ...
    MIMETYPE_UNKNOWN: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self, o: ClipDescription, /) -> None: ...
    @typing.overload
    def __init__(self, label: java.lang.CharSequence, mimeTypes: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def compareMimeTypes(concreteType: str | java.lang.String, desiredType: str | java.lang.String, /) -> bool: ...
    def describeContents(self) -> int: ...
    def filterMimeTypes(self, mimeType: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getClassificationStatus(self) -> int: ...
    def getConfidenceScore(self, entity: str | java.lang.String, /) -> float: ...
    def getExtras(self) -> android.os.PersistableBundle: ...
    def getLabel(self) -> java.lang.CharSequence: ...
    def getMimeType(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getMimeTypeCount(self) -> int: ...
    def getTimestamp(self) -> int: ...
    def hasMimeType(self, mimeType: str | java.lang.String, /) -> bool: ...
    def isStyledText(self) -> bool: ...
    def setExtras(self, extras: android.os.PersistableBundle, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ClipboardManager(android.text.ClipboardManager):
    def addPrimaryClipChangedListener(self, what: ClipboardManager.OnPrimaryClipChangedListener, /) -> None: ...
    def clearPrimaryClip(self) -> None: ...
    def getPrimaryClip(self) -> ClipData | None: ...
    def getPrimaryClipDescription(self) -> ClipDescription | None: ...
    def getText(self) -> java.lang.CharSequence: ...
    def hasPrimaryClip(self) -> bool: ...
    def hasText(self) -> bool: ...
    def removePrimaryClipChangedListener(self, what: ClipboardManager.OnPrimaryClipChangedListener, /) -> None: ...
    def setPrimaryClip(self, clip: ClipData, /) -> None: ...
    def setText(self, text: java.lang.CharSequence, /) -> None: ...

    class OnPrimaryClipChangedListener(java.lang.Object):
        def onPrimaryClipChanged(self) -> None: ...

class ComponentCallbacks(java.lang.Object):
    def onConfigurationChanged(self, arg1: android.content.res.Configuration, /) -> None: ...
    def onLowMemory(self) -> None: ...

class ComponentCallbacks2(ComponentCallbacks):
    TRIM_MEMORY_BACKGROUND: typing.ClassVar[int] = ...
    TRIM_MEMORY_COMPLETE: typing.ClassVar[int] = ...
    TRIM_MEMORY_MODERATE: typing.ClassVar[int] = ...
    TRIM_MEMORY_RUNNING_CRITICAL: typing.ClassVar[int] = ...
    TRIM_MEMORY_RUNNING_LOW: typing.ClassVar[int] = ...
    TRIM_MEMORY_RUNNING_MODERATE: typing.ClassVar[int] = ...
    TRIM_MEMORY_UI_HIDDEN: typing.ClassVar[int] = ...
    def onTrimMemory(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class ComponentName(android.os.Parcelable, java.lang.Cloneable, java.lang.Comparable[ComponentName]):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ComponentName]] = ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, pkg: Context, cls: typing.Type[java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, pkg: Context, cls: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, pkg: str | java.lang.String, cls: str | java.lang.String, /) -> None: ...
    def clone(self) -> ComponentName: ...
    def compareTo(self, that: ComponentName, /) -> int: ...
    @typing.overload
    @staticmethod
    def createRelative(pkg: Context, cls: str | java.lang.String, /) -> ComponentName: ...
    @typing.overload
    @staticmethod
    def createRelative(pkg: str | java.lang.String, cls: str | java.lang.String, /) -> ComponentName: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flattenToShortString(self) -> str | None: ...
    def flattenToString(self) -> str: ...
    def getClassName(self) -> str: ...
    def getPackageName(self) -> str: ...
    def getShortClassName(self) -> str: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def readFromParcel(in_: android.os.Parcel, /) -> ComponentName | None: ...
    def toShortString(self) -> str: ...
    def toString(self) -> str: ...
    @staticmethod
    def unflattenFromString(str: str | java.lang.String, /) -> ComponentName | None: ...
    @typing.overload
    @staticmethod
    def writeToParcel(c: ComponentName, out: android.os.Parcel, /) -> None: ...
    @typing.overload
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...


_ContentProvider__PipeDataWriter__T = typing.TypeVar('_ContentProvider__PipeDataWriter__T')  # <T>
class ContentProvider(ComponentCallbacks2):
    def __init__(self) -> None: ...
    @typing.overload
    def applyBatch(self, operations: java.util.ArrayList[ContentProviderOperation], /) -> java.chaquopy.JavaArray[ContentProviderResult]: ...
    @typing.overload
    def applyBatch(self, authority: str | java.lang.String, operations: java.util.ArrayList[ContentProviderOperation], /) -> java.chaquopy.JavaArray[ContentProviderResult]: ...
    def attachInfo(self, context: Context, info: android.content.pm.ProviderInfo, /) -> None: ...
    def bulkInsert(self, uri: android.net.Uri, values: java.chaquopy.JavaArray[ContentValues], /) -> int: ...
    @typing.overload
    def call(self, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    @typing.overload
    def call(self, authority: str | java.lang.String, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def canonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    def clearCallingIdentity(self) -> ContentProvider.CallingIdentity: ...
    @typing.overload
    def delete(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def delete(self, arg1: android.net.Uri, arg2: str | java.lang.String, arg3: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def dump(self, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getCallingAttributionSource(self) -> AttributionSource | None: ...
    def getCallingAttributionTag(self) -> str | None: ...
    def getCallingPackage(self) -> str | None: ...
    def getCallingPackageUnchecked(self) -> str | None: ...
    def getContext(self) -> Context | None: ...
    def getPathPermissions(self) -> java.chaquopy.JavaArray[android.content.pm.PathPermission] | None: ...
    def getReadPermission(self) -> str | None: ...
    def getStreamTypes(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getType(self, arg1: android.net.Uri, /) -> str | None: ...
    def getTypeAnonymous(self, uri: android.net.Uri, /) -> str | None: ...
    def getWritePermission(self) -> str | None: ...
    @typing.overload
    def insert(self, arg1: android.net.Uri, arg2: ContentValues, /) -> android.net.Uri | None: ...
    @typing.overload
    def insert(self, uri: android.net.Uri, values: ContentValues, extras: android.os.Bundle, /) -> android.net.Uri | None: ...
    def isTemporary(self) -> bool: ...
    def onCallingPackageChanged(self) -> None: ...
    def onConfigurationChanged(self, newConfig: android.content.res.Configuration, /) -> None: ...
    def onCreate(self) -> bool: ...
    def onLowMemory(self) -> None: ...
    def onTrimMemory(self, level: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def openAssetFile(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openAssetFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor | None: ...
    @typing.overload
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor | None: ...
    def openFileHelper(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor: ...
    _openPipeHelper__T = typing.TypeVar('_openPipeHelper__T')  # <T>
    def openPipeHelper(self, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, args: _openPipeHelper__T, func: ContentProvider.PipeDataWriter[_openPipeHelper__T], /) -> android.os.ParcelFileDescriptor: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, arg1: android.net.Uri, arg2: java.chaquopy.JavaArray[java.lang.String], arg3: str | java.lang.String, arg4: java.chaquopy.JavaArray[java.lang.String], arg5: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    def refresh(self, uri: android.net.Uri, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> bool: ...
    def requireContext(self) -> Context: ...
    def restoreCallingIdentity(self, identity: ContentProvider.CallingIdentity, /) -> None: ...
    def setPathPermissions(self, permissions: java.chaquopy.JavaArray[android.content.pm.PathPermission], /) -> None: ...
    def setReadPermission(self, permission: str | java.lang.String, /) -> None: ...
    def setWritePermission(self, permission: str | java.lang.String, /) -> None: ...
    def shutdown(self) -> None: ...
    def uncanonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    @typing.overload
    def update(self, uri: android.net.Uri, values: ContentValues, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def update(self, arg1: android.net.Uri, arg2: ContentValues, arg3: str | java.lang.String, arg4: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    class PipeDataWriter(java.lang.Object, typing.Generic[_ContentProvider__PipeDataWriter__T]):
        def writeDataToPipe(self, arg1: android.os.ParcelFileDescriptor, arg2: android.net.Uri, arg3: str | java.lang.String, arg4: android.os.Bundle, arg5: _ContentProvider__PipeDataWriter__T, /) -> None: ...

    class CallingIdentity(java.lang.Object): ...

class ContentProviderClient(java.lang.AutoCloseable):
    @typing.overload
    def applyBatch(self, operations: java.util.ArrayList[ContentProviderOperation], /) -> java.chaquopy.JavaArray[ContentProviderResult]: ...
    @typing.overload
    def applyBatch(self, authority: str | java.lang.String, operations: java.util.ArrayList[ContentProviderOperation], /) -> java.chaquopy.JavaArray[ContentProviderResult]: ...
    def bulkInsert(self, url: android.net.Uri, initialValues: java.chaquopy.JavaArray[ContentValues], /) -> int: ...
    @typing.overload
    def call(self, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    @typing.overload
    def call(self, authority: str | java.lang.String, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    def canonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    def close(self) -> None: ...
    @typing.overload
    def delete(self, url: android.net.Uri, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def delete(self, url: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def finalize(self) -> None: ...
    def getLocalContentProvider(self) -> ContentProvider | None: ...
    def getStreamTypes(self, url: android.net.Uri, mimeTypeFilter: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getType(self, url: android.net.Uri, /) -> str | None: ...
    @typing.overload
    def insert(self, url: android.net.Uri, initialValues: ContentValues, /) -> android.net.Uri | None: ...
    @typing.overload
    def insert(self, url: android.net.Uri, initialValues: ContentValues, extras: android.os.Bundle, /) -> android.net.Uri | None: ...
    @typing.overload
    def openAssetFile(self, url: android.net.Uri, mode: str | java.lang.String, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openAssetFile(self, url: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openFile(self, url: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor | None: ...
    @typing.overload
    def openFile(self, url: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor | None: ...
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openTypedAssetFileDescriptor(self, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openTypedAssetFileDescriptor(self, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, url: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    def refresh(self, url: android.net.Uri, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> bool: ...
    def release(self) -> bool: ...
    def uncanonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    @typing.overload
    def update(self, url: android.net.Uri, values: ContentValues, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def update(self, url: android.net.Uri, values: ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

class ContentProviderOperation(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentProviderOperation]] = ...
    def apply(self, provider: ContentProvider, backRefs: java.chaquopy.JavaArray[ContentProviderResult], numBackRefs: int | java.jint | java.lang.Integer, /) -> ContentProviderResult: ...
    def describeContents(self) -> int: ...
    def getUri(self) -> android.net.Uri: ...
    def isAssertQuery(self) -> bool: ...
    def isCall(self) -> bool: ...
    def isDelete(self) -> bool: ...
    def isExceptionAllowed(self) -> bool: ...
    def isInsert(self) -> bool: ...
    def isReadOperation(self) -> bool: ...
    def isUpdate(self) -> bool: ...
    def isWriteOperation(self) -> bool: ...
    def isYieldAllowed(self) -> bool: ...
    @staticmethod
    def newAssertQuery(uri: android.net.Uri, /) -> ContentProviderOperation.Builder: ...
    @staticmethod
    def newCall(uri: android.net.Uri, method: str | java.lang.String, arg: str | java.lang.String, /) -> ContentProviderOperation.Builder: ...
    @staticmethod
    def newDelete(uri: android.net.Uri, /) -> ContentProviderOperation.Builder: ...
    @staticmethod
    def newInsert(uri: android.net.Uri, /) -> ContentProviderOperation.Builder: ...
    @staticmethod
    def newUpdate(uri: android.net.Uri, /) -> ContentProviderOperation.Builder: ...
    def resolveExtrasBackReferences(self, backRefs: java.chaquopy.JavaArray[ContentProviderResult], numBackRefs: int | java.jint | java.lang.Integer, /) -> android.os.Bundle | None: ...
    def resolveSelectionArgsBackReferences(self, backRefs: java.chaquopy.JavaArray[ContentProviderResult], numBackRefs: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def resolveValueBackReferences(self, backRefs: java.chaquopy.JavaArray[ContentProviderResult], numBackRefs: int | java.jint | java.lang.Integer, /) -> ContentValues | None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def build(self) -> ContentProviderOperation: ...
        def withExceptionAllowed(self, exceptionAllowed: bool | java.jboolean | java.lang.Boolean, /) -> ContentProviderOperation.Builder: ...
        def withExpectedCount(self, count: int | java.jint | java.lang.Integer, /) -> ContentProviderOperation.Builder: ...
        def withExtra(self, key: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withExtraBackReference(self, key: str | java.lang.String, fromIndex: int | java.jint | java.lang.Integer, /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withExtraBackReference(self, key: str | java.lang.String, fromIndex: int | java.jint | java.lang.Integer, fromKey: str | java.lang.String, /) -> ContentProviderOperation.Builder: ...
        def withExtras(self, extras: android.os.Bundle, /) -> ContentProviderOperation.Builder: ...
        def withSelection(self, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withSelectionBackReference(self, index: int | java.jint | java.lang.Integer, fromIndex: int | java.jint | java.lang.Integer, /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withSelectionBackReference(self, index: int | java.jint | java.lang.Integer, fromIndex: int | java.jint | java.lang.Integer, fromKey: str | java.lang.String, /) -> ContentProviderOperation.Builder: ...
        def withValue(self, key: str | java.lang.String, value: java.lang.Object | int | bool | float | str, /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withValueBackReference(self, key: str | java.lang.String, fromIndex: int | java.jint | java.lang.Integer, /) -> ContentProviderOperation.Builder: ...
        @typing.overload
        def withValueBackReference(self, key: str | java.lang.String, fromIndex: int | java.jint | java.lang.Integer, fromKey: str | java.lang.String, /) -> ContentProviderOperation.Builder: ...
        def withValueBackReferences(self, backReferences: ContentValues, /) -> ContentProviderOperation.Builder: ...
        def withValues(self, values: ContentValues, /) -> ContentProviderOperation.Builder: ...
        def withYieldAllowed(self, yieldAllowed: bool | java.jboolean | java.lang.Boolean, /) -> ContentProviderOperation.Builder: ...

class ContentProviderResult(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentProviderResult]] = ...
    count: int = ...
    exception: java.lang.Throwable = ...
    extras: android.os.Bundle = ...
    uri: android.net.Uri = ...
    @typing.overload
    def __init__(self, count: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def __init__(self, extras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, exception: java.lang.Throwable, /) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class ContentQueryMap(java.util.Observable):
    def __init__(self, cursor: android.database.Cursor, columnNameOfKey: str | java.lang.String, keepUpdated: bool | java.jboolean | java.lang.Boolean, handlerForUpdateNotifications: android.os.Handler, /) -> None: ...
    def close(self) -> None: ...
    def finalize(self) -> None: ...
    def getRows(self) -> java.util.Map[java.lang.String, ContentValues]: ...
    def getValues(self, rowName: str | java.lang.String, /) -> ContentValues | None: ...
    def requery(self) -> None: ...
    def setKeepUpdated(self, keepUpdated: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class ContentResolver(java.lang.Object):
    ANY_CURSOR_ITEM_TYPE: typing.ClassVar[str] = ...
    CURSOR_DIR_BASE_TYPE: typing.ClassVar[str] = ...
    CURSOR_ITEM_BASE_TYPE: typing.ClassVar[str] = ...
    EXTRA_HONORED_ARGS: typing.ClassVar[str] = ...
    EXTRA_REFRESH_SUPPORTED: typing.ClassVar[str] = ...
    EXTRA_SIZE: typing.ClassVar[str] = ...
    EXTRA_TOTAL_COUNT: typing.ClassVar[str] = ...
    NOTIFY_DELETE: typing.ClassVar[int] = ...
    NOTIFY_INSERT: typing.ClassVar[int] = ...
    NOTIFY_SKIP_NOTIFY_FOR_DESCENDANTS: typing.ClassVar[int] = ...
    NOTIFY_SYNC_TO_NETWORK: typing.ClassVar[int] = ...
    NOTIFY_UPDATE: typing.ClassVar[int] = ...
    QUERY_ARG_GROUP_COLUMNS: typing.ClassVar[str] = ...
    QUERY_ARG_LIMIT: typing.ClassVar[str] = ...
    QUERY_ARG_OFFSET: typing.ClassVar[str] = ...
    QUERY_ARG_SORT_COLLATION: typing.ClassVar[str] = ...
    QUERY_ARG_SORT_COLUMNS: typing.ClassVar[str] = ...
    QUERY_ARG_SORT_DIRECTION: typing.ClassVar[str] = ...
    QUERY_ARG_SORT_LOCALE: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_GROUP_BY: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_HAVING: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_LIMIT: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_SELECTION: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_SELECTION_ARGS: typing.ClassVar[str] = ...
    QUERY_ARG_SQL_SORT_ORDER: typing.ClassVar[str] = ...
    QUERY_SORT_DIRECTION_ASCENDING: typing.ClassVar[int] = ...
    QUERY_SORT_DIRECTION_DESCENDING: typing.ClassVar[int] = ...
    SCHEME_ANDROID_RESOURCE: typing.ClassVar[str] = ...
    SCHEME_CONTENT: typing.ClassVar[str] = ...
    SCHEME_FILE: typing.ClassVar[str] = ...
    SYNC_EXTRAS_ACCOUNT: typing.ClassVar[str] = ...
    SYNC_EXTRAS_DISCARD_LOCAL_DELETIONS: typing.ClassVar[str] = ...
    SYNC_EXTRAS_DO_NOT_RETRY: typing.ClassVar[str] = ...
    SYNC_EXTRAS_EXPEDITED: typing.ClassVar[str] = ...
    SYNC_EXTRAS_FORCE: typing.ClassVar[str] = ...
    SYNC_EXTRAS_IGNORE_BACKOFF: typing.ClassVar[str] = ...
    SYNC_EXTRAS_IGNORE_SETTINGS: typing.ClassVar[str] = ...
    SYNC_EXTRAS_INITIALIZE: typing.ClassVar[str] = ...
    SYNC_EXTRAS_MANUAL: typing.ClassVar[str] = ...
    SYNC_EXTRAS_OVERRIDE_TOO_MANY_DELETIONS: typing.ClassVar[str] = ...
    SYNC_EXTRAS_REQUIRE_CHARGING: typing.ClassVar[str] = ...
    SYNC_EXTRAS_SCHEDULE_AS_EXPEDITED_JOB: typing.ClassVar[str] = ...
    SYNC_EXTRAS_UPLOAD: typing.ClassVar[str] = ...
    SYNC_OBSERVER_TYPE_ACTIVE: typing.ClassVar[int] = ...
    SYNC_OBSERVER_TYPE_PENDING: typing.ClassVar[int] = ...
    SYNC_OBSERVER_TYPE_SETTINGS: typing.ClassVar[int] = ...
    def __init__(self, context: Context, /) -> None: ...
    @typing.overload
    def acquireContentProviderClient(self, uri: android.net.Uri, /) -> ContentProviderClient | None: ...
    @typing.overload
    def acquireContentProviderClient(self, name: str | java.lang.String, /) -> ContentProviderClient | None: ...
    @typing.overload
    def acquireUnstableContentProviderClient(self, uri: android.net.Uri, /) -> ContentProviderClient | None: ...
    @typing.overload
    def acquireUnstableContentProviderClient(self, name: str | java.lang.String, /) -> ContentProviderClient | None: ...
    @staticmethod
    def addPeriodicSync(account: android.accounts.Account, authority: str | java.lang.String, extras: android.os.Bundle, pollFrequency: int | java.jlong | java.lang.Long, /) -> None: ...
    @staticmethod
    def addStatusChangeListener(mask: int | java.jint | java.lang.Integer, callback: SyncStatusObserver, /) -> java.lang.Object: ...
    def applyBatch(self, authority: str | java.lang.String, operations: java.util.ArrayList[ContentProviderOperation], /) -> java.chaquopy.JavaArray[ContentProviderResult]: ...
    def bulkInsert(self, url: android.net.Uri, values: java.chaquopy.JavaArray[ContentValues], /) -> int: ...
    @typing.overload
    def call(self, uri: android.net.Uri, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    @typing.overload
    def call(self, authority: str | java.lang.String, method: str | java.lang.String, arg: str | java.lang.String, extras: android.os.Bundle, /) -> android.os.Bundle | None: ...
    @typing.overload
    @staticmethod
    def cancelSync(request: SyncRequest, /) -> None: ...
    @typing.overload
    def cancelSync(self, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    @staticmethod
    def cancelSync(account: android.accounts.Account, authority: str | java.lang.String, /) -> None: ...
    def canonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    @typing.overload
    def delete(self, url: android.net.Uri, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def delete(self, url: android.net.Uri, where: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @staticmethod
    def getCurrentSync() -> SyncInfo | None: ...
    @staticmethod
    def getCurrentSyncs() -> java.util.List[SyncInfo]: ...
    @staticmethod
    def getIsSyncable(account: android.accounts.Account, authority: str | java.lang.String, /) -> int: ...
    @staticmethod
    def getMasterSyncAutomatically() -> bool: ...
    def getOutgoingPersistedUriPermissions(self) -> java.util.List[UriPermission]: ...
    @staticmethod
    def getPeriodicSyncs(account: android.accounts.Account, authority: str | java.lang.String, /) -> java.util.List[PeriodicSync]: ...
    def getPersistedUriPermissions(self) -> java.util.List[UriPermission]: ...
    def getStreamTypes(self, url: android.net.Uri, mimeTypeFilter: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    @staticmethod
    def getSyncAdapterTypes() -> java.chaquopy.JavaArray[SyncAdapterType]: ...
    @staticmethod
    def getSyncAutomatically(account: android.accounts.Account, authority: str | java.lang.String, /) -> bool: ...
    def getType(self, url: android.net.Uri, /) -> str | None: ...
    def getTypeInfo(self, mimeType: str | java.lang.String, /) -> ContentResolver.MimeTypeInfo: ...
    @typing.overload
    def insert(self, url: android.net.Uri, values: ContentValues, /) -> android.net.Uri | None: ...
    @typing.overload
    def insert(self, url: android.net.Uri, values: ContentValues, extras: android.os.Bundle, /) -> android.net.Uri | None: ...
    @staticmethod
    def isSyncActive(account: android.accounts.Account, authority: str | java.lang.String, /) -> bool: ...
    @staticmethod
    def isSyncPending(account: android.accounts.Account, authority: str | java.lang.String, /) -> bool: ...
    def loadThumbnail(self, uri: android.net.Uri, size: android.util.Size, signal: android.os.CancellationSignal, /) -> android.graphics.Bitmap | None: ...
    @typing.overload
    def notifyChange(self, uri: android.net.Uri, observer: android.database.ContentObserver, /) -> None: ...
    @typing.overload
    def notifyChange(self, uri: android.net.Uri, observer: android.database.ContentObserver, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def notifyChange(self, uri: android.net.Uri, observer: android.database.ContentObserver, syncToNetwork: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def notifyChange(self, uris: java.util.Collection[android.net.Uri], observer: android.database.ContentObserver, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def openAssetFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openAssetFileDescriptor(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openAssetFileDescriptor(self, uri: android.net.Uri, mode: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    def openFile(self, uri: android.net.Uri, mode: str | java.lang.String, signal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor | None: ...
    @typing.overload
    def openFileDescriptor(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> android.os.ParcelFileDescriptor | None: ...
    @typing.overload
    def openFileDescriptor(self, uri: android.net.Uri, mode: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.os.ParcelFileDescriptor | None: ...
    def openInputStream(self, uri: android.net.Uri, /) -> java.io.InputStream | None: ...
    @typing.overload
    def openOutputStream(self, uri: android.net.Uri, /) -> java.io.OutputStream | None: ...
    @typing.overload
    def openOutputStream(self, uri: android.net.Uri, mode: str | java.lang.String, /) -> java.io.OutputStream | None: ...
    def openTypedAssetFile(self, uri: android.net.Uri, mimeTypeFilter: str | java.lang.String, opts: android.os.Bundle, signal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openTypedAssetFileDescriptor(self, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def openTypedAssetFileDescriptor(self, uri: android.net.Uri, mimeType: str | java.lang.String, opts: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.content.res.AssetFileDescriptor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], queryArgs: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor | None: ...
    @typing.overload
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, cancellationSignal: android.os.CancellationSignal, /) -> android.database.Cursor | None: ...
    def refresh(self, url: android.net.Uri, extras: android.os.Bundle, cancellationSignal: android.os.CancellationSignal, /) -> bool: ...
    def registerContentObserver(self, uri: android.net.Uri, notifyForDescendants: bool | java.jboolean | java.lang.Boolean, observer: android.database.ContentObserver, /) -> None: ...
    def releasePersistableUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def removePeriodicSync(account: android.accounts.Account, authority: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
    @staticmethod
    def removeStatusChangeListener(handle: java.lang.Object | int | bool | float | str, /) -> None: ...
    @typing.overload
    @staticmethod
    def requestSync(request: SyncRequest, /) -> None: ...
    @typing.overload
    @staticmethod
    def requestSync(account: android.accounts.Account, authority: str | java.lang.String, extras: android.os.Bundle, /) -> None: ...
    @staticmethod
    def setIsSyncable(account: android.accounts.Account, authority: str | java.lang.String, syncable: int | java.jint | java.lang.Integer, /) -> None: ...
    @staticmethod
    def setMasterSyncAutomatically(sync: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @staticmethod
    def setSyncAutomatically(account: android.accounts.Account, authority: str | java.lang.String, sync: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def startSync(self, uri: android.net.Uri, extras: android.os.Bundle, /) -> None: ...
    def takePersistableUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    def uncanonicalize(self, url: android.net.Uri, /) -> android.net.Uri | None: ...
    def unregisterContentObserver(self, observer: android.database.ContentObserver, /) -> None: ...
    @typing.overload
    def update(self, uri: android.net.Uri, values: ContentValues, extras: android.os.Bundle, /) -> int: ...
    @typing.overload
    def update(self, uri: android.net.Uri, values: ContentValues, where: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    @staticmethod
    def validateSyncExtrasBundle(extras: android.os.Bundle, /) -> None: ...
    @typing.overload
    @staticmethod
    def wrap(wrapped: ContentProvider, /) -> ContentResolver: ...
    @typing.overload
    @staticmethod
    def wrap(wrapped: ContentProviderClient, /) -> ContentResolver: ...

    class MimeTypeInfo(java.lang.Object):
        def getContentDescription(self) -> java.lang.CharSequence: ...
        def getIcon(self) -> android.graphics.drawable.Icon: ...
        def getLabel(self) -> java.lang.CharSequence: ...

class ContentUris(java.lang.Object):
    def __init__(self) -> None: ...
    @staticmethod
    def appendId(builder: android.net.Uri.Builder, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri.Builder: ...
    @staticmethod
    def parseId(contentUri: android.net.Uri, /) -> int: ...
    @staticmethod
    def removeId(contentUri: android.net.Uri, /) -> android.net.Uri: ...
    @staticmethod
    def withAppendedId(contentUri: android.net.Uri, id: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...

class ContentValues(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ContentValues]] = ...
    TAG: typing.ClassVar[str] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, size: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, from_: ContentValues, /) -> None: ...
    def clear(self) -> None: ...
    def containsKey(self, key: str | java.lang.String, /) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, object: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def get(self, key: str | java.lang.String, /) -> java.lang.Object: ...
    def getAsBoolean(self, key: str | java.lang.String, /) -> bool: ...
    def getAsByte(self, key: str | java.lang.String, /) -> int: ...
    def getAsByteArray(self, key: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte: ...
    def getAsDouble(self, key: str | java.lang.String, /) -> float: ...
    def getAsFloat(self, key: str | java.lang.String, /) -> float: ...
    def getAsInteger(self, key: str | java.lang.String, /) -> int: ...
    def getAsLong(self, key: str | java.lang.String, /) -> int: ...
    def getAsShort(self, key: str | java.lang.String, /) -> int: ...
    def getAsString(self, key: str | java.lang.String, /) -> str: ...
    def hashCode(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def keySet(self) -> java.util.Set[java.lang.String]: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: int | java.jbyte | java.lang.Byte, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: float | java.jdouble | java.lang.Double, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: int | java.jshort | java.lang.Short, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: str | java.lang.String, /) -> None: ...
    @typing.overload
    def put(self, key: str | java.lang.String, value: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def putAll(self, other: ContentValues, /) -> None: ...
    def putNull(self, key: str | java.lang.String, /) -> None: ...
    def remove(self, key: str | java.lang.String, /) -> None: ...
    def size(self) -> int: ...
    def toString(self) -> str: ...
    def valueSet(self) -> java.util.Set[java.util.Map.Entry[java.lang.String, java.lang.Object]]: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class Context(java.lang.Object):
    ACCESSIBILITY_SERVICE: typing.ClassVar[str] = ...
    ACCOUNT_SERVICE: typing.ClassVar[str] = ...
    ACTIVITY_SERVICE: typing.ClassVar[str] = ...
    ADVANCED_PROTECTION_SERVICE: typing.ClassVar[str] = ...
    ALARM_SERVICE: typing.ClassVar[str] = ...
    APPWIDGET_SERVICE: typing.ClassVar[str] = ...
    APP_FUNCTION_SERVICE: typing.ClassVar[str] = ...
    APP_OPS_SERVICE: typing.ClassVar[str] = ...
    APP_SEARCH_SERVICE: typing.ClassVar[str] = ...
    AUDIO_SERVICE: typing.ClassVar[str] = ...
    BATTERY_SERVICE: typing.ClassVar[str] = ...
    BIND_ABOVE_CLIENT: typing.ClassVar[int] = ...
    BIND_ADJUST_WITH_ACTIVITY: typing.ClassVar[int] = ...
    BIND_ALLOW_ACTIVITY_STARTS: typing.ClassVar[int] = ...
    BIND_ALLOW_OOM_MANAGEMENT: typing.ClassVar[int] = ...
    BIND_AUTO_CREATE: typing.ClassVar[int] = ...
    BIND_DEBUG_UNBIND: typing.ClassVar[int] = ...
    BIND_EXTERNAL_SERVICE: typing.ClassVar[int] = ...
    BIND_EXTERNAL_SERVICE_LONG: typing.ClassVar[int] = ...
    BIND_IMPORTANT: typing.ClassVar[int] = ...
    BIND_INCLUDE_CAPABILITIES: typing.ClassVar[int] = ...
    BIND_NOT_FOREGROUND: typing.ClassVar[int] = ...
    BIND_NOT_PERCEPTIBLE: typing.ClassVar[int] = ...
    BIND_PACKAGE_ISOLATED_PROCESS: typing.ClassVar[int] = ...
    BIND_SHARED_ISOLATED_PROCESS: typing.ClassVar[int] = ...
    BIND_WAIVE_PRIORITY: typing.ClassVar[int] = ...
    BIOMETRIC_SERVICE: typing.ClassVar[str] = ...
    BLOB_STORE_SERVICE: typing.ClassVar[str] = ...
    BLUETOOTH_SERVICE: typing.ClassVar[str] = ...
    BUGREPORT_SERVICE: typing.ClassVar[str] = ...
    CAMERA_SERVICE: typing.ClassVar[str] = ...
    CAPTIONING_SERVICE: typing.ClassVar[str] = ...
    CARRIER_CONFIG_SERVICE: typing.ClassVar[str] = ...
    CLIPBOARD_SERVICE: typing.ClassVar[str] = ...
    COMPANION_DEVICE_SERVICE: typing.ClassVar[str] = ...
    CONNECTIVITY_DIAGNOSTICS_SERVICE: typing.ClassVar[str] = ...
    CONNECTIVITY_SERVICE: typing.ClassVar[str] = ...
    CONSUMER_IR_SERVICE: typing.ClassVar[str] = ...
    CONTACT_KEYS_SERVICE: typing.ClassVar[str] = ...
    CONTEXT_IGNORE_SECURITY: typing.ClassVar[int] = ...
    CONTEXT_INCLUDE_CODE: typing.ClassVar[int] = ...
    CONTEXT_RESTRICTED: typing.ClassVar[int] = ...
    CREDENTIAL_SERVICE: typing.ClassVar[str] = ...
    CROSS_PROFILE_APPS_SERVICE: typing.ClassVar[str] = ...
    DEVICE_ID_DEFAULT: typing.ClassVar[int] = ...
    DEVICE_ID_INVALID: typing.ClassVar[int] = ...
    DEVICE_LOCK_SERVICE: typing.ClassVar[str] = ...
    DEVICE_POLICY_SERVICE: typing.ClassVar[str] = ...
    DISPLAY_HASH_SERVICE: typing.ClassVar[str] = ...
    DISPLAY_SERVICE: typing.ClassVar[str] = ...
    DOMAIN_VERIFICATION_SERVICE: typing.ClassVar[str] = ...
    DOWNLOAD_SERVICE: typing.ClassVar[str] = ...
    DROPBOX_SERVICE: typing.ClassVar[str] = ...
    EUICC_SERVICE: typing.ClassVar[str] = ...
    FILE_INTEGRITY_SERVICE: typing.ClassVar[str] = ...
    FINGERPRINT_SERVICE: typing.ClassVar[str] = ...
    GAME_SERVICE: typing.ClassVar[str] = ...
    GRAMMATICAL_INFLECTION_SERVICE: typing.ClassVar[str] = ...
    HARDWARE_PROPERTIES_SERVICE: typing.ClassVar[str] = ...
    HEALTHCONNECT_SERVICE: typing.ClassVar[str] = ...
    INPUT_METHOD_SERVICE: typing.ClassVar[str] = ...
    INPUT_SERVICE: typing.ClassVar[str] = ...
    IPSEC_SERVICE: typing.ClassVar[str] = ...
    JOB_SCHEDULER_SERVICE: typing.ClassVar[str] = ...
    KEYGUARD_SERVICE: typing.ClassVar[str] = ...
    KEYSTORE_SERVICE: typing.ClassVar[str] = ...
    LAUNCHER_APPS_SERVICE: typing.ClassVar[str] = ...
    LAYOUT_INFLATER_SERVICE: typing.ClassVar[str] = ...
    LOCALE_SERVICE: typing.ClassVar[str] = ...
    LOCATION_SERVICE: typing.ClassVar[str] = ...
    MEDIA_COMMUNICATION_SERVICE: typing.ClassVar[str] = ...
    MEDIA_METRICS_SERVICE: typing.ClassVar[str] = ...
    MEDIA_PROJECTION_SERVICE: typing.ClassVar[str] = ...
    MEDIA_QUALITY_SERVICE: typing.ClassVar[str] = ...
    MEDIA_ROUTER_SERVICE: typing.ClassVar[str] = ...
    MEDIA_SESSION_SERVICE: typing.ClassVar[str] = ...
    MIDI_SERVICE: typing.ClassVar[str] = ...
    MODE_APPEND: typing.ClassVar[int] = ...
    MODE_ENABLE_WRITE_AHEAD_LOGGING: typing.ClassVar[int] = ...
    MODE_MULTI_PROCESS: typing.ClassVar[int] = ...
    MODE_NO_LOCALIZED_COLLATORS: typing.ClassVar[int] = ...
    MODE_PRIVATE: typing.ClassVar[int] = ...
    MODE_WORLD_READABLE: typing.ClassVar[int] = ...
    MODE_WORLD_WRITEABLE: typing.ClassVar[int] = ...
    NETWORK_STATS_SERVICE: typing.ClassVar[str] = ...
    NFC_SERVICE: typing.ClassVar[str] = ...
    NOTIFICATION_SERVICE: typing.ClassVar[str] = ...
    NSD_SERVICE: typing.ClassVar[str] = ...
    OVERLAY_SERVICE: typing.ClassVar[str] = ...
    PEOPLE_SERVICE: typing.ClassVar[str] = ...
    PERFORMANCE_HINT_SERVICE: typing.ClassVar[str] = ...
    PERSISTENT_DATA_BLOCK_SERVICE: typing.ClassVar[str] = ...
    POWER_SERVICE: typing.ClassVar[str] = ...
    PRINT_SERVICE: typing.ClassVar[str] = ...
    PROFILING_SERVICE: typing.ClassVar[str] = ...
    RECEIVER_EXPORTED: typing.ClassVar[int] = ...
    RECEIVER_NOT_EXPORTED: typing.ClassVar[int] = ...
    RECEIVER_VISIBLE_TO_INSTANT_APPS: typing.ClassVar[int] = ...
    RESTRICTIONS_SERVICE: typing.ClassVar[str] = ...
    ROLE_SERVICE: typing.ClassVar[str] = ...
    SATELLITE_SERVICE: typing.ClassVar[str] = ...
    SEARCH_SERVICE: typing.ClassVar[str] = ...
    SECURITY_STATE_SERVICE: typing.ClassVar[str] = ...
    SENSOR_SERVICE: typing.ClassVar[str] = ...
    SHORTCUT_SERVICE: typing.ClassVar[str] = ...
    STATUS_BAR_SERVICE: typing.ClassVar[str] = ...
    STORAGE_SERVICE: typing.ClassVar[str] = ...
    STORAGE_STATS_SERVICE: typing.ClassVar[str] = ...
    SYSTEM_HEALTH_SERVICE: typing.ClassVar[str] = ...
    TELECOM_SERVICE: typing.ClassVar[str] = ...
    TELEPHONY_IMS_SERVICE: typing.ClassVar[str] = ...
    TELEPHONY_SERVICE: typing.ClassVar[str] = ...
    TELEPHONY_SUBSCRIPTION_SERVICE: typing.ClassVar[str] = ...
    TETHERING_SERVICE: typing.ClassVar[str] = ...
    TEXT_CLASSIFICATION_SERVICE: typing.ClassVar[str] = ...
    TEXT_SERVICES_MANAGER_SERVICE: typing.ClassVar[str] = ...
    TV_AD_SERVICE: typing.ClassVar[str] = ...
    TV_INPUT_SERVICE: typing.ClassVar[str] = ...
    TV_INTERACTIVE_APP_SERVICE: typing.ClassVar[str] = ...
    UI_MODE_SERVICE: typing.ClassVar[str] = ...
    USAGE_STATS_SERVICE: typing.ClassVar[str] = ...
    USB_SERVICE: typing.ClassVar[str] = ...
    USER_SERVICE: typing.ClassVar[str] = ...
    VIBRATOR_MANAGER_SERVICE: typing.ClassVar[str] = ...
    VIBRATOR_SERVICE: typing.ClassVar[str] = ...
    VIRTUAL_DEVICE_SERVICE: typing.ClassVar[str] = ...
    VPN_MANAGEMENT_SERVICE: typing.ClassVar[str] = ...
    WALLPAPER_SERVICE: typing.ClassVar[str] = ...
    WIFI_AWARE_SERVICE: typing.ClassVar[str] = ...
    WIFI_P2P_SERVICE: typing.ClassVar[str] = ...
    WIFI_RTT_RANGING_SERVICE: typing.ClassVar[str] = ...
    WIFI_SERVICE: typing.ClassVar[str] = ...
    WINDOW_SERVICE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @typing.overload
    def bindIsolatedService(self, service: Intent, flags: int | java.jint | java.lang.Integer, instanceName: str | java.lang.String, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindIsolatedService(self, service: Intent, flags: Context.BindServiceFlags, instanceName: str | java.lang.String, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindService(self, arg1: Intent, arg2: ServiceConnection, arg3: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, conn: ServiceConnection, flags: Context.BindServiceFlags, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, flags: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, flags: Context.BindServiceFlags, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindServiceAsUser(self, service: Intent, conn: ServiceConnection, flags: int | java.jint | java.lang.Integer, user: android.os.UserHandle, /) -> bool: ...
    @typing.overload
    def bindServiceAsUser(self, service: Intent, conn: ServiceConnection, flags: Context.BindServiceFlags, user: android.os.UserHandle, /) -> bool: ...
    def checkCallingOrSelfPermission(self, arg1: str | java.lang.String, /) -> int: ...
    def checkCallingOrSelfUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkCallingOrSelfUriPermissions(self, uris: java.util.List[android.net.Uri], modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def checkCallingPermission(self, arg1: str | java.lang.String, /) -> int: ...
    def checkCallingUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkCallingUriPermissions(self, uris: java.util.List[android.net.Uri], modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def checkContentUriPermissionFull(self, uri: android.net.Uri, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkPermission(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkSelfPermission(self, arg1: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def checkUriPermission(self, arg1: android.net.Uri, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkUriPermissions(self, uris: java.util.List[android.net.Uri], pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def clearWallpaper(self) -> None: ...
    def createAttributionContext(self, attributionTag: str | java.lang.String, /) -> Context: ...
    def createConfigurationContext(self, arg1: android.content.res.Configuration, /) -> Context: ...
    def createContext(self, contextParams: ContextParams, /) -> Context: ...
    def createContextForSplit(self, arg1: str | java.lang.String, /) -> Context: ...
    def createDeviceContext(self, deviceId: int | java.jint | java.lang.Integer, /) -> Context: ...
    def createDeviceProtectedStorageContext(self) -> Context: ...
    def createDisplayContext(self, arg1: android.view.Display, /) -> Context: ...
    def createPackageContext(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> Context: ...
    @typing.overload
    def createWindowContext(self, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> Context: ...
    @typing.overload
    def createWindowContext(self, display: android.view.Display, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> Context: ...
    def databaseList(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def deleteDatabase(self, arg1: str | java.lang.String, /) -> bool: ...
    def deleteFile(self, arg1: str | java.lang.String, /) -> bool: ...
    def deleteSharedPreferences(self, arg1: str | java.lang.String, /) -> bool: ...
    def enforceCallingOrSelfPermission(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def enforceCallingOrSelfUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    def enforceCallingPermission(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> None: ...
    def enforceCallingUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, arg3: str | java.lang.String, /) -> None: ...
    def enforcePermission(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, /) -> None: ...
    @typing.overload
    def enforceUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: str | java.lang.String, /) -> None: ...
    @typing.overload
    def enforceUriPermission(self, arg1: android.net.Uri, arg2: str | java.lang.String, arg3: str | java.lang.String, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: int | java.jint | java.lang.Integer, arg7: str | java.lang.String, /) -> None: ...
    def fileList(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getApplicationContext(self) -> Context: ...
    def getApplicationInfo(self) -> android.content.pm.ApplicationInfo: ...
    def getAssets(self) -> android.content.res.AssetManager: ...
    def getAttributionSource(self) -> AttributionSource: ...
    def getAttributionTag(self) -> str | None: ...
    def getCacheDir(self) -> java.io.File: ...
    def getClassLoader(self) -> java.lang.ClassLoader: ...
    def getCodeCacheDir(self) -> java.io.File: ...
    def getColor(self, id: int | java.jint | java.lang.Integer, /) -> int: ...
    def getColorStateList(self, id: int | java.jint | java.lang.Integer, /) -> android.content.res.ColorStateList: ...
    def getContentResolver(self) -> ContentResolver: ...
    def getDataDir(self) -> java.io.File: ...
    def getDatabasePath(self, arg1: str | java.lang.String, /) -> java.io.File: ...
    def getDeviceId(self) -> int: ...
    def getDir(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> java.io.File: ...
    def getDisplay(self) -> android.view.Display: ...
    def getDrawable(self, id: int | java.jint | java.lang.Integer, /) -> android.graphics.drawable.Drawable | None: ...
    def getExternalCacheDir(self) -> java.io.File | None: ...
    def getExternalCacheDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getExternalFilesDir(self, arg1: str | java.lang.String, /) -> java.io.File | None: ...
    def getExternalFilesDirs(self, arg1: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getExternalMediaDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getFileStreamPath(self, arg1: str | java.lang.String, /) -> java.io.File: ...
    def getFilesDir(self) -> java.io.File: ...
    def getMainExecutor(self) -> java.util.concurrent.Executor: ...
    def getMainLooper(self) -> android.os.Looper: ...
    def getNoBackupFilesDir(self) -> java.io.File: ...
    def getObbDir(self) -> java.io.File: ...
    def getObbDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getOpPackageName(self) -> str: ...
    def getPackageCodePath(self) -> str: ...
    def getPackageManager(self) -> android.content.pm.PackageManager: ...
    def getPackageName(self) -> str: ...
    def getPackageResourcePath(self) -> str: ...
    def getParams(self) -> ContextParams | None: ...
    def getResources(self) -> android.content.res.Resources | None: ...
    def getSharedPreferences(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> SharedPreferences: ...
    @typing.overload
    def getString(self, resId: int | java.jint | java.lang.Integer, /) -> str: ...
    @typing.overload
    def getString(self, resId: int | java.jint | java.lang.Integer, /, *formatArgs: java.lang.Object) -> str: ...
    _getSystemService_0__T = typing.TypeVar('_getSystemService_0__T')  # <T>
    @typing.overload
    def getSystemService(self, serviceClass: typing.Type[_getSystemService_0__T], /) -> _getSystemService_0__T: ...
    @typing.overload
    def getSystemService(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getSystemServiceName(self, arg1: typing.Type[java.lang.Object], /) -> str | None: ...
    def getText(self, resId: int | java.jint | java.lang.Integer, /) -> java.lang.CharSequence: ...
    def getTheme(self) -> android.content.res.Resources.Theme | None: ...
    def getWallpaper(self) -> android.graphics.drawable.Drawable: ...
    def getWallpaperDesiredMinimumHeight(self) -> int: ...
    def getWallpaperDesiredMinimumWidth(self) -> int: ...
    def grantUriPermission(self, arg1: str | java.lang.String, arg2: android.net.Uri, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    def isDeviceProtectedStorage(self) -> bool: ...
    def isRestricted(self) -> bool: ...
    def isUiContext(self) -> bool: ...
    def moveDatabaseFrom(self, arg1: Context, arg2: str | java.lang.String, /) -> bool: ...
    def moveSharedPreferencesFrom(self, arg1: Context, arg2: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def obtainStyledAttributes(self, attrs: java.chaquopy.JavaArrayJInt, /) -> android.content.res.TypedArray: ...
    @typing.overload
    def obtainStyledAttributes(self, resid: int | java.jint | java.lang.Integer, attrs: java.chaquopy.JavaArrayJInt, /) -> android.content.res.TypedArray: ...
    @typing.overload
    def obtainStyledAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, /) -> android.content.res.TypedArray: ...
    @typing.overload
    def obtainStyledAttributes(self, set: android.util.AttributeSet, attrs: java.chaquopy.JavaArrayJInt, defStyleAttr: int | java.jint | java.lang.Integer, defStyleRes: int | java.jint | java.lang.Integer, /) -> android.content.res.TypedArray: ...
    def openFileInput(self, arg1: str | java.lang.String, /) -> java.io.FileInputStream: ...
    def openFileOutput(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> java.io.FileOutputStream: ...
    @typing.overload
    def openOrCreateDatabase(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: android.database.sqlite.SQLiteDatabase.CursorFactory, /) -> android.database.sqlite.SQLiteDatabase: ...
    @typing.overload
    def openOrCreateDatabase(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, arg3: android.database.sqlite.SQLiteDatabase.CursorFactory, arg4: android.database.DatabaseErrorHandler, /) -> android.database.sqlite.SQLiteDatabase: ...
    def peekWallpaper(self) -> android.graphics.drawable.Drawable: ...
    def registerComponentCallbacks(self, callback: ComponentCallbacks, /) -> None: ...
    def registerDeviceIdChangeListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.IntConsumer, /) -> None: ...
    @typing.overload
    def registerReceiver(self, arg1: BroadcastReceiver, arg2: IntentFilter, /) -> Intent | None: ...
    @typing.overload
    def registerReceiver(self, arg1: BroadcastReceiver, arg2: IntentFilter, arg3: int | java.jint | java.lang.Integer, /) -> Intent | None: ...
    @typing.overload
    def registerReceiver(self, arg1: BroadcastReceiver, arg2: IntentFilter, arg3: str | java.lang.String, arg4: android.os.Handler, /) -> Intent | None: ...
    @typing.overload
    def registerReceiver(self, arg1: BroadcastReceiver, arg2: IntentFilter, arg3: str | java.lang.String, arg4: android.os.Handler, arg5: int | java.jint | java.lang.Integer, /) -> Intent | None: ...
    def removeStickyBroadcast(self, arg1: Intent, /) -> None: ...
    def removeStickyBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, /) -> None: ...
    def revokeSelfPermissionOnKill(self, permName: str | java.lang.String, /) -> None: ...
    def revokeSelfPermissionsOnKill(self, permissions: java.util.Collection[java.lang.String], /) -> None: ...
    @typing.overload
    def revokeUriPermission(self, arg1: android.net.Uri, arg2: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def revokeUriPermission(self, arg1: str | java.lang.String, arg2: android.net.Uri, arg3: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, arg1: Intent, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, arg1: Intent, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, /) -> None: ...
    @typing.overload
    def sendBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, arg3: str | java.lang.String, /) -> None: ...
    def sendBroadcastWithMultiplePermissions(self, intent: Intent, receiverPermissions: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, arg1: Intent, arg2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, arg1: Intent, arg2: str | java.lang.String, arg3: BroadcastReceiver, arg4: android.os.Handler, arg5: int | java.jint | java.lang.Integer, arg6: str | java.lang.String, arg7: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, receiverAppOp: str | java.lang.String, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    def sendOrderedBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, arg3: str | java.lang.String, arg4: BroadcastReceiver, arg5: android.os.Handler, arg6: int | java.jint | java.lang.Integer, arg7: str | java.lang.String, arg8: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendStickyBroadcast(self, arg1: Intent, /) -> None: ...
    @typing.overload
    def sendStickyBroadcast(self, intent: Intent, options: android.os.Bundle, /) -> None: ...
    def sendStickyBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, /) -> None: ...
    def sendStickyOrderedBroadcast(self, arg1: Intent, arg2: BroadcastReceiver, arg3: android.os.Handler, arg4: int | java.jint | java.lang.Integer, arg5: str | java.lang.String, arg6: android.os.Bundle, /) -> None: ...
    def sendStickyOrderedBroadcastAsUser(self, arg1: Intent, arg2: android.os.UserHandle, arg3: BroadcastReceiver, arg4: android.os.Handler, arg5: int | java.jint | java.lang.Integer, arg6: str | java.lang.String, arg7: android.os.Bundle, /) -> None: ...
    def setTheme(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setWallpaper(self, arg1: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def setWallpaper(self, arg1: java.io.InputStream, /) -> None: ...
    @typing.overload
    def startActivities(self, arg1: java.chaquopy.JavaArray[Intent], /) -> None: ...
    @typing.overload
    def startActivities(self, arg1: java.chaquopy.JavaArray[Intent], arg2: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivity(self, arg1: Intent, /) -> None: ...
    @typing.overload
    def startActivity(self, arg1: Intent, arg2: android.os.Bundle, /) -> None: ...
    def startForegroundService(self, arg1: Intent, /) -> ComponentName | None: ...
    def startInstrumentation(self, arg1: ComponentName, arg2: str | java.lang.String, arg3: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def startIntentSender(self, arg1: IntentSender, arg2: Intent, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startIntentSender(self, arg1: IntentSender, arg2: Intent, arg3: int | java.jint | java.lang.Integer, arg4: int | java.jint | java.lang.Integer, arg5: int | java.jint | java.lang.Integer, arg6: android.os.Bundle, /) -> None: ...
    def startService(self, arg1: Intent, /) -> ComponentName | None: ...
    def stopService(self, arg1: Intent, /) -> bool: ...
    def unbindService(self, arg1: ServiceConnection, /) -> None: ...
    def unregisterComponentCallbacks(self, callback: ComponentCallbacks, /) -> None: ...
    def unregisterDeviceIdChangeListener(self, listener: java.util.function.IntConsumer, /) -> None: ...
    def unregisterReceiver(self, arg1: BroadcastReceiver, /) -> None: ...
    def updateServiceGroup(self, conn: ServiceConnection, group: int | java.jint | java.lang.Integer, importance: int | java.jint | java.lang.Integer, /) -> None: ...

    class BindServiceFlags(java.lang.Object):
        @staticmethod
        def of(value: int | java.jlong | java.lang.Long, /) -> Context.BindServiceFlags: ...

class ContextParams(java.lang.Object):
    def getAttributionTag(self) -> str | None: ...
    def getNextAttributionSource(self) -> AttributionSource | None: ...
    def shouldRegisterAttributionSource(self) -> bool: ...

    class Builder(java.lang.Object):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, params: ContextParams, /) -> None: ...
        def build(self) -> ContextParams: ...
        def setAttributionTag(self, attributionTag: str | java.lang.String, /) -> ContextParams.Builder: ...
        def setNextAttributionSource(self, next: AttributionSource, /) -> ContextParams.Builder: ...
        def setShouldRegisterAttributionSource(self, shouldRegister: bool | java.jboolean | java.lang.Boolean, /) -> ContextParams.Builder: ...

class ContextWrapper(Context):
    def __init__(self, base: Context, /) -> None: ...
    def attachBaseContext(self, base: Context, /) -> None: ...
    def bindIsolatedService(self, service: Intent, flags: int | java.jint | java.lang.Integer, instanceName: str | java.lang.String, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, conn: ServiceConnection, flags: int | java.jint | java.lang.Integer, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, conn: ServiceConnection, flags: Context.BindServiceFlags, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, flags: int | java.jint | java.lang.Integer, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindService(self, service: Intent, flags: Context.BindServiceFlags, executor: java.util.concurrent.Executor, conn: ServiceConnection, /) -> bool: ...
    @typing.overload
    def bindServiceAsUser(self, service: Intent, conn: ServiceConnection, flags: int | java.jint | java.lang.Integer, user: android.os.UserHandle, /) -> bool: ...
    @typing.overload
    def bindServiceAsUser(self, service: Intent, conn: ServiceConnection, flags: Context.BindServiceFlags, user: android.os.UserHandle, /) -> bool: ...
    def checkCallingOrSelfPermission(self, permission: str | java.lang.String, /) -> int: ...
    def checkCallingOrSelfUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkCallingOrSelfUriPermissions(self, uris: java.util.List[android.net.Uri], modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def checkCallingPermission(self, permission: str | java.lang.String, /) -> int: ...
    def checkCallingUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkCallingUriPermissions(self, uris: java.util.List[android.net.Uri], modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def checkContentUriPermissionFull(self, uri: android.net.Uri, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkPermission(self, permission: str | java.lang.String, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkSelfPermission(self, permission: str | java.lang.String, /) -> int: ...
    @typing.overload
    def checkUriPermission(self, uri: android.net.Uri, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    @typing.overload
    def checkUriPermission(self, uri: android.net.Uri, readPermission: str | java.lang.String, writePermission: str | java.lang.String, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> int: ...
    def checkUriPermissions(self, uris: java.util.List[android.net.Uri], pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, /) -> java.chaquopy.JavaArrayJInt: ...
    def clearWallpaper(self) -> None: ...
    def createAttributionContext(self, attributionTag: str | java.lang.String, /) -> Context: ...
    def createConfigurationContext(self, overrideConfiguration: android.content.res.Configuration, /) -> Context: ...
    def createContext(self, contextParams: ContextParams, /) -> Context: ...
    def createContextForSplit(self, splitName: str | java.lang.String, /) -> Context: ...
    def createDeviceContext(self, deviceId: int | java.jint | java.lang.Integer, /) -> Context: ...
    def createDeviceProtectedStorageContext(self) -> Context: ...
    def createDisplayContext(self, display: android.view.Display, /) -> Context: ...
    def createPackageContext(self, packageName: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> Context: ...
    @typing.overload
    def createWindowContext(self, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> Context: ...
    @typing.overload
    def createWindowContext(self, display: android.view.Display, type: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> Context: ...
    def databaseList(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def deleteDatabase(self, name: str | java.lang.String, /) -> bool: ...
    def deleteFile(self, name: str | java.lang.String, /) -> bool: ...
    def deleteSharedPreferences(self, name: str | java.lang.String, /) -> bool: ...
    def enforceCallingOrSelfPermission(self, permission: str | java.lang.String, message: str | java.lang.String, /) -> None: ...
    def enforceCallingOrSelfUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def enforceCallingPermission(self, permission: str | java.lang.String, message: str | java.lang.String, /) -> None: ...
    def enforceCallingUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def enforcePermission(self, permission: str | java.lang.String, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def enforceUriPermission(self, uri: android.net.Uri, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def enforceUriPermission(self, uri: android.net.Uri, readPermission: str | java.lang.String, writePermission: str | java.lang.String, pid: int | java.jint | java.lang.Integer, uid: int | java.jint | java.lang.Integer, modeFlags: int | java.jint | java.lang.Integer, message: str | java.lang.String, /) -> None: ...
    def fileList(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getApplicationContext(self) -> Context: ...
    def getApplicationInfo(self) -> android.content.pm.ApplicationInfo: ...
    def getAssets(self) -> android.content.res.AssetManager: ...
    def getAttributionSource(self) -> AttributionSource: ...
    def getAttributionTag(self) -> str | None: ...
    def getBaseContext(self) -> Context: ...
    def getCacheDir(self) -> java.io.File: ...
    def getClassLoader(self) -> java.lang.ClassLoader: ...
    def getCodeCacheDir(self) -> java.io.File: ...
    def getContentResolver(self) -> ContentResolver: ...
    def getDataDir(self) -> java.io.File: ...
    def getDatabasePath(self, name: str | java.lang.String, /) -> java.io.File: ...
    def getDeviceId(self) -> int: ...
    def getDir(self, name: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> java.io.File: ...
    def getDisplay(self) -> android.view.Display | None: ...
    def getExternalCacheDir(self) -> java.io.File | None: ...
    def getExternalCacheDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getExternalFilesDir(self, type: str | java.lang.String, /) -> java.io.File | None: ...
    def getExternalFilesDirs(self, type: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getExternalMediaDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getFileStreamPath(self, name: str | java.lang.String, /) -> java.io.File: ...
    def getFilesDir(self) -> java.io.File: ...
    def getMainExecutor(self) -> java.util.concurrent.Executor: ...
    def getMainLooper(self) -> android.os.Looper: ...
    def getNoBackupFilesDir(self) -> java.io.File: ...
    def getObbDir(self) -> java.io.File: ...
    def getObbDirs(self) -> java.chaquopy.JavaArray[java.io.File]: ...
    def getOpPackageName(self) -> str: ...
    def getPackageCodePath(self) -> str: ...
    def getPackageManager(self) -> android.content.pm.PackageManager: ...
    def getPackageName(self) -> str: ...
    def getPackageResourcePath(self) -> str: ...
    def getParams(self) -> ContextParams | None: ...
    def getResources(self) -> android.content.res.Resources: ...
    def getSharedPreferences(self, name: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> SharedPreferences: ...
    def getSystemService(self, name: str | java.lang.String, /) -> java.lang.Object: ...
    def getSystemServiceName(self, serviceClass: typing.Type[java.lang.Object], /) -> str: ...
    def getTheme(self) -> android.content.res.Resources.Theme: ...
    def getWallpaper(self) -> android.graphics.drawable.Drawable: ...
    def getWallpaperDesiredMinimumHeight(self) -> int: ...
    def getWallpaperDesiredMinimumWidth(self) -> int: ...
    def grantUriPermission(self, toPackage: str | java.lang.String, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    def isDeviceProtectedStorage(self) -> bool: ...
    def isRestricted(self) -> bool: ...
    def isUiContext(self) -> bool: ...
    def moveDatabaseFrom(self, sourceContext: Context, name: str | java.lang.String, /) -> bool: ...
    def moveSharedPreferencesFrom(self, sourceContext: Context, name: str | java.lang.String, /) -> bool: ...
    def openFileInput(self, name: str | java.lang.String, /) -> java.io.FileInputStream: ...
    def openFileOutput(self, name: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> java.io.FileOutputStream: ...
    @typing.overload
    def openOrCreateDatabase(self, name: str | java.lang.String, mode: int | java.jint | java.lang.Integer, factory: android.database.sqlite.SQLiteDatabase.CursorFactory, /) -> android.database.sqlite.SQLiteDatabase: ...
    @typing.overload
    def openOrCreateDatabase(self, name: str | java.lang.String, mode: int | java.jint | java.lang.Integer, factory: android.database.sqlite.SQLiteDatabase.CursorFactory, errorHandler: android.database.DatabaseErrorHandler, /) -> android.database.sqlite.SQLiteDatabase: ...
    def peekWallpaper(self) -> android.graphics.drawable.Drawable: ...
    def registerComponentCallbacks(self, callback: ComponentCallbacks, /) -> None: ...
    def registerDeviceIdChangeListener(self, executor: java.util.concurrent.Executor, listener: java.util.function.IntConsumer, /) -> None: ...
    @typing.overload
    def registerReceiver(self, receiver: BroadcastReceiver, filter: IntentFilter, /) -> Intent: ...
    @typing.overload
    def registerReceiver(self, receiver: BroadcastReceiver, filter: IntentFilter, flags: int | java.jint | java.lang.Integer, /) -> Intent: ...
    @typing.overload
    def registerReceiver(self, receiver: BroadcastReceiver, filter: IntentFilter, broadcastPermission: str | java.lang.String, scheduler: android.os.Handler, /) -> Intent: ...
    @typing.overload
    def registerReceiver(self, receiver: BroadcastReceiver, filter: IntentFilter, broadcastPermission: str | java.lang.String, scheduler: android.os.Handler, flags: int | java.jint | java.lang.Integer, /) -> Intent: ...
    def removeStickyBroadcast(self, intent: Intent, /) -> None: ...
    def removeStickyBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, /) -> None: ...
    def revokeSelfPermissionsOnKill(self, permissions: java.util.Collection[java.lang.String], /) -> None: ...
    @typing.overload
    def revokeUriPermission(self, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def revokeUriPermission(self, targetPackage: str | java.lang.String, uri: android.net.Uri, modeFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, intent: Intent, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, /) -> None: ...
    @typing.overload
    def sendBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, receiverPermission: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, options: android.os.Bundle, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, receiverPermission: str | java.lang.String, receiverAppOp: str | java.lang.String, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendOrderedBroadcast(self, intent: Intent, initialCode: int | java.jint | java.lang.Integer, receiverPermission: str | java.lang.String, receiverAppOp: str | java.lang.String, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialData: str | java.lang.String, initialExtras: android.os.Bundle, options: android.os.Bundle, /) -> None: ...
    def sendOrderedBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, receiverPermission: str | java.lang.String, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    @typing.overload
    def sendStickyBroadcast(self, intent: Intent, /) -> None: ...
    @typing.overload
    def sendStickyBroadcast(self, intent: Intent, options: android.os.Bundle, /) -> None: ...
    def sendStickyBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, /) -> None: ...
    def sendStickyOrderedBroadcast(self, intent: Intent, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    def sendStickyOrderedBroadcastAsUser(self, intent: Intent, user: android.os.UserHandle, resultReceiver: BroadcastReceiver, scheduler: android.os.Handler, initialCode: int | java.jint | java.lang.Integer, initialData: str | java.lang.String, initialExtras: android.os.Bundle, /) -> None: ...
    def setTheme(self, resid: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setWallpaper(self, bitmap: android.graphics.Bitmap, /) -> None: ...
    @typing.overload
    def setWallpaper(self, data: java.io.InputStream, /) -> None: ...
    @typing.overload
    def startActivities(self, intents: java.chaquopy.JavaArray[Intent], /) -> None: ...
    @typing.overload
    def startActivities(self, intents: java.chaquopy.JavaArray[Intent], options: android.os.Bundle, /) -> None: ...
    @typing.overload
    def startActivity(self, intent: Intent, /) -> None: ...
    @typing.overload
    def startActivity(self, intent: Intent, options: android.os.Bundle, /) -> None: ...
    def startForegroundService(self, service: Intent, /) -> ComponentName | None: ...
    def startInstrumentation(self, className: ComponentName, profileFile: str | java.lang.String, arguments: android.os.Bundle, /) -> bool: ...
    @typing.overload
    def startIntentSender(self, intent: IntentSender, fillInIntent: Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def startIntentSender(self, intent: IntentSender, fillInIntent: Intent, flagsMask: int | java.jint | java.lang.Integer, flagsValues: int | java.jint | java.lang.Integer, extraFlags: int | java.jint | java.lang.Integer, options: android.os.Bundle, /) -> None: ...
    def startService(self, service: Intent, /) -> ComponentName | None: ...
    def stopService(self, name: Intent, /) -> bool: ...
    def unbindService(self, conn: ServiceConnection, /) -> None: ...
    def unregisterComponentCallbacks(self, callback: ComponentCallbacks, /) -> None: ...
    def unregisterDeviceIdChangeListener(self, listener: java.util.function.IntConsumer, /) -> None: ...
    def unregisterReceiver(self, receiver: BroadcastReceiver, /) -> None: ...
    def updateServiceGroup(self, conn: ServiceConnection, group: int | java.jint | java.lang.Integer, importance: int | java.jint | java.lang.Integer, /) -> None: ...

class CursorLoader(AsyncTaskLoader[android.database.Cursor]):
    @typing.overload
    def __init__(self, context: Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: Context, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> None: ...
    def cancelLoadInBackground(self) -> None: ...
    def deliverResult(self, cursor: android.database.Cursor, /) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def getProjection(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSelection(self) -> str: ...
    def getSelectionArgs(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getSortOrder(self) -> str: ...
    def getUri(self) -> android.net.Uri: ...
    def loadInBackground(self) -> android.database.Cursor: ...
    def onCanceled(self, cursor: android.database.Cursor, /) -> None: ...
    def onReset(self) -> None: ...
    def onStartLoading(self) -> None: ...
    def onStopLoading(self) -> None: ...
    def setProjection(self, projection: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setSelection(self, selection: str | java.lang.String, /) -> None: ...
    def setSelectionArgs(self, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def setSortOrder(self, sortOrder: str | java.lang.String, /) -> None: ...
    def setUri(self, uri: android.net.Uri, /) -> None: ...

class DialogInterface(java.lang.Object):
    BUTTON1: typing.ClassVar[int] = ...
    BUTTON2: typing.ClassVar[int] = ...
    BUTTON3: typing.ClassVar[int] = ...
    BUTTON_NEGATIVE: typing.ClassVar[int] = ...
    BUTTON_NEUTRAL: typing.ClassVar[int] = ...
    BUTTON_POSITIVE: typing.ClassVar[int] = ...
    def cancel(self) -> None: ...
    def dismiss(self) -> None: ...

    class OnShowListener(java.lang.Object):
        def onShow(self, arg1: DialogInterface, /) -> None: ...

    class OnMultiChoiceClickListener(java.lang.Object):
        def onClick(self, arg1: DialogInterface, arg2: int | java.jint | java.lang.Integer, arg3: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class OnKeyListener(java.lang.Object):
        def onKey(self, arg1: DialogInterface, arg2: int | java.jint | java.lang.Integer, arg3: android.view.KeyEvent, /) -> bool: ...

    class OnDismissListener(java.lang.Object):
        def onDismiss(self, arg1: DialogInterface, /) -> None: ...

    class OnClickListener(java.lang.Object):
        def onClick(self, arg1: DialogInterface, arg2: int | java.jint | java.lang.Integer, /) -> None: ...

    class OnCancelListener(java.lang.Object):
        def onCancel(self, arg1: DialogInterface, /) -> None: ...

class Entity(java.lang.Object):
    def __init__(self, values: ContentValues, /) -> None: ...
    def addSubValue(self, uri: android.net.Uri, values: ContentValues, /) -> None: ...
    def getEntityValues(self) -> ContentValues: ...
    def getSubValues(self) -> java.util.ArrayList[Entity.NamedContentValues]: ...
    def toString(self) -> str: ...

    class NamedContentValues(java.lang.Object):
        uri: android.net.Uri = ...
        values: ContentValues = ...
        def __init__(self, uri: android.net.Uri, values: ContentValues, /) -> None: ...

class EntityIterator(java.util.Iterator[Entity]):
    def close(self) -> None: ...
    def reset(self) -> None: ...

class Intent(android.os.Parcelable, java.lang.Cloneable):
    ACTION_AIRPLANE_MODE_CHANGED: typing.ClassVar[str] = ...
    ACTION_ALL_APPS: typing.ClassVar[str] = ...
    ACTION_ANSWER: typing.ClassVar[str] = ...
    ACTION_APPLICATION_LOCALE_CHANGED: typing.ClassVar[str] = ...
    ACTION_APPLICATION_PREFERENCES: typing.ClassVar[str] = ...
    ACTION_APPLICATION_RESTRICTIONS_CHANGED: typing.ClassVar[str] = ...
    ACTION_APP_ERROR: typing.ClassVar[str] = ...
    ACTION_ASSIST: typing.ClassVar[str] = ...
    ACTION_ATTACH_DATA: typing.ClassVar[str] = ...
    ACTION_AUTO_REVOKE_PERMISSIONS: typing.ClassVar[str] = ...
    ACTION_BATTERY_CHANGED: typing.ClassVar[str] = ...
    ACTION_BATTERY_LOW: typing.ClassVar[str] = ...
    ACTION_BATTERY_OKAY: typing.ClassVar[str] = ...
    ACTION_BOOT_COMPLETED: typing.ClassVar[str] = ...
    ACTION_BUG_REPORT: typing.ClassVar[str] = ...
    ACTION_CALL: typing.ClassVar[str] = ...
    ACTION_CALL_BUTTON: typing.ClassVar[str] = ...
    ACTION_CAMERA_BUTTON: typing.ClassVar[str] = ...
    ACTION_CARRIER_SETUP: typing.ClassVar[str] = ...
    ACTION_CHOOSER: typing.ClassVar[str] = ...
    ACTION_CLOSE_SYSTEM_DIALOGS: typing.ClassVar[str] = ...
    ACTION_CONFIGURATION_CHANGED: typing.ClassVar[str] = ...
    ACTION_CREATE_DOCUMENT: typing.ClassVar[str] = ...
    ACTION_CREATE_NOTE: typing.ClassVar[str] = ...
    ACTION_CREATE_REMINDER: typing.ClassVar[str] = ...
    ACTION_CREATE_SHORTCUT: typing.ClassVar[str] = ...
    ACTION_DATE_CHANGED: typing.ClassVar[str] = ...
    ACTION_DEFAULT: typing.ClassVar[str] = ...
    ACTION_DEFINE: typing.ClassVar[str] = ...
    ACTION_DELETE: typing.ClassVar[str] = ...
    ACTION_DEVICE_STORAGE_LOW: typing.ClassVar[str] = ...
    ACTION_DEVICE_STORAGE_OK: typing.ClassVar[str] = ...
    ACTION_DIAL: typing.ClassVar[str] = ...
    ACTION_DOCK_EVENT: typing.ClassVar[str] = ...
    ACTION_DREAMING_STARTED: typing.ClassVar[str] = ...
    ACTION_DREAMING_STOPPED: typing.ClassVar[str] = ...
    ACTION_EDIT: typing.ClassVar[str] = ...
    ACTION_EXTERNAL_APPLICATIONS_AVAILABLE: typing.ClassVar[str] = ...
    ACTION_EXTERNAL_APPLICATIONS_UNAVAILABLE: typing.ClassVar[str] = ...
    ACTION_FACTORY_TEST: typing.ClassVar[str] = ...
    ACTION_GET_CONTENT: typing.ClassVar[str] = ...
    ACTION_GET_RESTRICTION_ENTRIES: typing.ClassVar[str] = ...
    ACTION_GTALK_SERVICE_CONNECTED: typing.ClassVar[str] = ...
    ACTION_GTALK_SERVICE_DISCONNECTED: typing.ClassVar[str] = ...
    ACTION_HEADSET_PLUG: typing.ClassVar[str] = ...
    ACTION_INPUT_METHOD_CHANGED: typing.ClassVar[str] = ...
    ACTION_INSERT: typing.ClassVar[str] = ...
    ACTION_INSERT_OR_EDIT: typing.ClassVar[str] = ...
    ACTION_INSTALL_FAILURE: typing.ClassVar[str] = ...
    ACTION_INSTALL_PACKAGE: typing.ClassVar[str] = ...
    ACTION_LAUNCH_CAPTURE_CONTENT_ACTIVITY_FOR_NOTE: typing.ClassVar[str] = ...
    ACTION_LOCALE_CHANGED: typing.ClassVar[str] = ...
    ACTION_LOCKED_BOOT_COMPLETED: typing.ClassVar[str] = ...
    ACTION_MAIN: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_ADDED: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_AVAILABLE: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_REMOVED: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_UNAVAILABLE: typing.ClassVar[str] = ...
    ACTION_MANAGED_PROFILE_UNLOCKED: typing.ClassVar[str] = ...
    ACTION_MANAGE_NETWORK_USAGE: typing.ClassVar[str] = ...
    ACTION_MANAGE_PACKAGE_STORAGE: typing.ClassVar[str] = ...
    ACTION_MANAGE_UNUSED_APPS: typing.ClassVar[str] = ...
    ACTION_MEDIA_BAD_REMOVAL: typing.ClassVar[str] = ...
    ACTION_MEDIA_BUTTON: typing.ClassVar[str] = ...
    ACTION_MEDIA_CHECKING: typing.ClassVar[str] = ...
    ACTION_MEDIA_EJECT: typing.ClassVar[str] = ...
    ACTION_MEDIA_MOUNTED: typing.ClassVar[str] = ...
    ACTION_MEDIA_NOFS: typing.ClassVar[str] = ...
    ACTION_MEDIA_REMOVED: typing.ClassVar[str] = ...
    ACTION_MEDIA_SCANNER_FINISHED: typing.ClassVar[str] = ...
    ACTION_MEDIA_SCANNER_SCAN_FILE: typing.ClassVar[str] = ...
    ACTION_MEDIA_SCANNER_STARTED: typing.ClassVar[str] = ...
    ACTION_MEDIA_SHARED: typing.ClassVar[str] = ...
    ACTION_MEDIA_UNMOUNTABLE: typing.ClassVar[str] = ...
    ACTION_MEDIA_UNMOUNTED: typing.ClassVar[str] = ...
    ACTION_MY_PACKAGE_REPLACED: typing.ClassVar[str] = ...
    ACTION_MY_PACKAGE_SUSPENDED: typing.ClassVar[str] = ...
    ACTION_MY_PACKAGE_UNSUSPENDED: typing.ClassVar[str] = ...
    ACTION_NEW_OUTGOING_CALL: typing.ClassVar[str] = ...
    ACTION_OPEN_DOCUMENT: typing.ClassVar[str] = ...
    ACTION_OPEN_DOCUMENT_TREE: typing.ClassVar[str] = ...
    ACTION_PACKAGES_SUSPENDED: typing.ClassVar[str] = ...
    ACTION_PACKAGES_UNSUSPENDED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_ADDED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_CHANGED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_DATA_CLEARED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_FIRST_LAUNCH: typing.ClassVar[str] = ...
    ACTION_PACKAGE_FULLY_REMOVED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_INSTALL: typing.ClassVar[str] = ...
    ACTION_PACKAGE_NEEDS_VERIFICATION: typing.ClassVar[str] = ...
    ACTION_PACKAGE_REMOVED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_REPLACED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_RESTARTED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_UNSTOPPED: typing.ClassVar[str] = ...
    ACTION_PACKAGE_VERIFIED: typing.ClassVar[str] = ...
    ACTION_PASTE: typing.ClassVar[str] = ...
    ACTION_PICK: typing.ClassVar[str] = ...
    ACTION_PICK_ACTIVITY: typing.ClassVar[str] = ...
    ACTION_POWER_CONNECTED: typing.ClassVar[str] = ...
    ACTION_POWER_DISCONNECTED: typing.ClassVar[str] = ...
    ACTION_POWER_USAGE_SUMMARY: typing.ClassVar[str] = ...
    ACTION_PROCESS_TEXT: typing.ClassVar[str] = ...
    ACTION_PROFILE_ACCESSIBLE: typing.ClassVar[str] = ...
    ACTION_PROFILE_ADDED: typing.ClassVar[str] = ...
    ACTION_PROFILE_AVAILABLE: typing.ClassVar[str] = ...
    ACTION_PROFILE_INACCESSIBLE: typing.ClassVar[str] = ...
    ACTION_PROFILE_REMOVED: typing.ClassVar[str] = ...
    ACTION_PROFILE_UNAVAILABLE: typing.ClassVar[str] = ...
    ACTION_PROVIDER_CHANGED: typing.ClassVar[str] = ...
    ACTION_QUICK_CLOCK: typing.ClassVar[str] = ...
    ACTION_QUICK_VIEW: typing.ClassVar[str] = ...
    ACTION_REBOOT: typing.ClassVar[str] = ...
    ACTION_RUN: typing.ClassVar[str] = ...
    ACTION_SAFETY_CENTER: typing.ClassVar[str] = ...
    ACTION_SCREEN_OFF: typing.ClassVar[str] = ...
    ACTION_SCREEN_ON: typing.ClassVar[str] = ...
    ACTION_SEARCH: typing.ClassVar[str] = ...
    ACTION_SEARCH_LONG_PRESS: typing.ClassVar[str] = ...
    ACTION_SEND: typing.ClassVar[str] = ...
    ACTION_SENDTO: typing.ClassVar[str] = ...
    ACTION_SEND_MULTIPLE: typing.ClassVar[str] = ...
    ACTION_SET_WALLPAPER: typing.ClassVar[str] = ...
    ACTION_SHOW_APP_INFO: typing.ClassVar[str] = ...
    ACTION_SHOW_WORK_APPS: typing.ClassVar[str] = ...
    ACTION_SHUTDOWN: typing.ClassVar[str] = ...
    ACTION_SYNC: typing.ClassVar[str] = ...
    ACTION_SYSTEM_TUTORIAL: typing.ClassVar[str] = ...
    ACTION_TIMEZONE_CHANGED: typing.ClassVar[str] = ...
    ACTION_TIME_CHANGED: typing.ClassVar[str] = ...
    ACTION_TIME_TICK: typing.ClassVar[str] = ...
    ACTION_TRANSLATE: typing.ClassVar[str] = ...
    ACTION_UID_REMOVED: typing.ClassVar[str] = ...
    ACTION_UMS_CONNECTED: typing.ClassVar[str] = ...
    ACTION_UMS_DISCONNECTED: typing.ClassVar[str] = ...
    ACTION_UNARCHIVE_PACKAGE: typing.ClassVar[str] = ...
    ACTION_UNINSTALL_PACKAGE: typing.ClassVar[str] = ...
    ACTION_USER_BACKGROUND: typing.ClassVar[str] = ...
    ACTION_USER_FOREGROUND: typing.ClassVar[str] = ...
    ACTION_USER_INITIALIZE: typing.ClassVar[str] = ...
    ACTION_USER_PRESENT: typing.ClassVar[str] = ...
    ACTION_USER_UNLOCKED: typing.ClassVar[str] = ...
    ACTION_VIEW: typing.ClassVar[str] = ...
    ACTION_VIEW_LOCUS: typing.ClassVar[str] = ...
    ACTION_VIEW_PERMISSION_USAGE: typing.ClassVar[str] = ...
    ACTION_VIEW_PERMISSION_USAGE_FOR_PERIOD: typing.ClassVar[str] = ...
    ACTION_VOICE_COMMAND: typing.ClassVar[str] = ...
    ACTION_WALLPAPER_CHANGED: typing.ClassVar[str] = ...
    ACTION_WEB_SEARCH: typing.ClassVar[str] = ...
    CAPTURE_CONTENT_FOR_NOTE_BLOCKED_BY_ADMIN: typing.ClassVar[int] = ...
    CAPTURE_CONTENT_FOR_NOTE_FAILED: typing.ClassVar[int] = ...
    CAPTURE_CONTENT_FOR_NOTE_SUCCESS: typing.ClassVar[int] = ...
    CAPTURE_CONTENT_FOR_NOTE_USER_CANCELED: typing.ClassVar[int] = ...
    CAPTURE_CONTENT_FOR_NOTE_WINDOW_MODE_UNSUPPORTED: typing.ClassVar[int] = ...
    CATEGORY_ACCESSIBILITY_SHORTCUT_TARGET: typing.ClassVar[str] = ...
    CATEGORY_ALTERNATIVE: typing.ClassVar[str] = ...
    CATEGORY_APP_BROWSER: typing.ClassVar[str] = ...
    CATEGORY_APP_CALCULATOR: typing.ClassVar[str] = ...
    CATEGORY_APP_CALENDAR: typing.ClassVar[str] = ...
    CATEGORY_APP_CONTACTS: typing.ClassVar[str] = ...
    CATEGORY_APP_EMAIL: typing.ClassVar[str] = ...
    CATEGORY_APP_FILES: typing.ClassVar[str] = ...
    CATEGORY_APP_FITNESS: typing.ClassVar[str] = ...
    CATEGORY_APP_GALLERY: typing.ClassVar[str] = ...
    CATEGORY_APP_MAPS: typing.ClassVar[str] = ...
    CATEGORY_APP_MARKET: typing.ClassVar[str] = ...
    CATEGORY_APP_MESSAGING: typing.ClassVar[str] = ...
    CATEGORY_APP_MUSIC: typing.ClassVar[str] = ...
    CATEGORY_APP_WEATHER: typing.ClassVar[str] = ...
    CATEGORY_BROWSABLE: typing.ClassVar[str] = ...
    CATEGORY_CAR_DOCK: typing.ClassVar[str] = ...
    CATEGORY_CAR_MODE: typing.ClassVar[str] = ...
    CATEGORY_DEFAULT: typing.ClassVar[str] = ...
    CATEGORY_DESK_DOCK: typing.ClassVar[str] = ...
    CATEGORY_DEVELOPMENT_PREFERENCE: typing.ClassVar[str] = ...
    CATEGORY_EMBED: typing.ClassVar[str] = ...
    CATEGORY_FRAMEWORK_INSTRUMENTATION_TEST: typing.ClassVar[str] = ...
    CATEGORY_HE_DESK_DOCK: typing.ClassVar[str] = ...
    CATEGORY_HOME: typing.ClassVar[str] = ...
    CATEGORY_INFO: typing.ClassVar[str] = ...
    CATEGORY_LAUNCHER: typing.ClassVar[str] = ...
    CATEGORY_LEANBACK_LAUNCHER: typing.ClassVar[str] = ...
    CATEGORY_LE_DESK_DOCK: typing.ClassVar[str] = ...
    CATEGORY_MONKEY: typing.ClassVar[str] = ...
    CATEGORY_OPENABLE: typing.ClassVar[str] = ...
    CATEGORY_PREFERENCE: typing.ClassVar[str] = ...
    CATEGORY_SAMPLE_CODE: typing.ClassVar[str] = ...
    CATEGORY_SECONDARY_HOME: typing.ClassVar[str] = ...
    CATEGORY_SELECTED_ALTERNATIVE: typing.ClassVar[str] = ...
    CATEGORY_TAB: typing.ClassVar[str] = ...
    CATEGORY_TEST: typing.ClassVar[str] = ...
    CATEGORY_TYPED_OPENABLE: typing.ClassVar[str] = ...
    CATEGORY_UNIT_TEST: typing.ClassVar[str] = ...
    CATEGORY_VOICE: typing.ClassVar[str] = ...
    CATEGORY_VR_HOME: typing.ClassVar[str] = ...
    CHOOSER_CONTENT_TYPE_ALBUM: typing.ClassVar[int] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Intent]] = ...
    EXTRA_ALARM_COUNT: typing.ClassVar[str] = ...
    EXTRA_ALLOW_MULTIPLE: typing.ClassVar[str] = ...
    EXTRA_ALLOW_REPLACE: typing.ClassVar[str] = ...
    EXTRA_ALTERNATE_INTENTS: typing.ClassVar[str] = ...
    EXTRA_ARCHIVAL: typing.ClassVar[str] = ...
    EXTRA_ASSIST_CONTEXT: typing.ClassVar[str] = ...
    EXTRA_ASSIST_INPUT_DEVICE_ID: typing.ClassVar[str] = ...
    EXTRA_ASSIST_INPUT_HINT_KEYBOARD: typing.ClassVar[str] = ...
    EXTRA_ASSIST_PACKAGE: typing.ClassVar[str] = ...
    EXTRA_ASSIST_UID: typing.ClassVar[str] = ...
    EXTRA_ATTRIBUTION_TAGS: typing.ClassVar[str] = ...
    EXTRA_AUTO_LAUNCH_SINGLE_CHOICE: typing.ClassVar[str] = ...
    EXTRA_BCC: typing.ClassVar[str] = ...
    EXTRA_BUG_REPORT: typing.ClassVar[str] = ...
    EXTRA_CAPTURE_CONTENT_FOR_NOTE_STATUS_CODE: typing.ClassVar[str] = ...
    EXTRA_CC: typing.ClassVar[str] = ...
    EXTRA_CHANGED_COMPONENT_NAME: typing.ClassVar[str] = ...
    EXTRA_CHANGED_COMPONENT_NAME_LIST: typing.ClassVar[str] = ...
    EXTRA_CHANGED_PACKAGE_LIST: typing.ClassVar[str] = ...
    EXTRA_CHANGED_UID_LIST: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_ADDITIONAL_CONTENT_URI: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_CONTENT_TYPE_HINT: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_CUSTOM_ACTIONS: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_FOCUSED_ITEM_POSITION: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_MODIFY_SHARE_ACTION: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_REFINEMENT_INTENT_SENDER: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_RESULT: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_RESULT_INTENT_SENDER: typing.ClassVar[str] = ...
    EXTRA_CHOOSER_TARGETS: typing.ClassVar[str] = ...
    EXTRA_CHOSEN_COMPONENT: typing.ClassVar[str] = ...
    EXTRA_CHOSEN_COMPONENT_INTENT_SENDER: typing.ClassVar[str] = ...
    EXTRA_COMPONENT_NAME: typing.ClassVar[str] = ...
    EXTRA_CONTENT_ANNOTATIONS: typing.ClassVar[str] = ...
    EXTRA_CONTENT_QUERY: typing.ClassVar[str] = ...
    EXTRA_DATA_REMOVED: typing.ClassVar[str] = ...
    EXTRA_DOCK_STATE: typing.ClassVar[str] = ...
    EXTRA_DOCK_STATE_CAR: typing.ClassVar[int] = ...
    EXTRA_DOCK_STATE_DESK: typing.ClassVar[int] = ...
    EXTRA_DOCK_STATE_HE_DESK: typing.ClassVar[int] = ...
    EXTRA_DOCK_STATE_LE_DESK: typing.ClassVar[int] = ...
    EXTRA_DOCK_STATE_UNDOCKED: typing.ClassVar[int] = ...
    EXTRA_DONT_KILL_APP: typing.ClassVar[str] = ...
    EXTRA_DURATION_MILLIS: typing.ClassVar[str] = ...
    EXTRA_EMAIL: typing.ClassVar[str] = ...
    EXTRA_END_TIME: typing.ClassVar[str] = ...
    EXTRA_EXCLUDE_COMPONENTS: typing.ClassVar[str] = ...
    EXTRA_FROM_STORAGE: typing.ClassVar[str] = ...
    EXTRA_HTML_TEXT: typing.ClassVar[str] = ...
    EXTRA_INDEX: typing.ClassVar[str] = ...
    EXTRA_INITIAL_INTENTS: typing.ClassVar[str] = ...
    EXTRA_INSTALLER_PACKAGE_NAME: typing.ClassVar[str] = ...
    EXTRA_INTENT: typing.ClassVar[str] = ...
    EXTRA_KEY_EVENT: typing.ClassVar[str] = ...
    EXTRA_LOCALE_LIST: typing.ClassVar[str] = ...
    EXTRA_LOCAL_ONLY: typing.ClassVar[str] = ...
    EXTRA_LOCUS_ID: typing.ClassVar[str] = ...
    EXTRA_METADATA_TEXT: typing.ClassVar[str] = ...
    EXTRA_MIME_TYPES: typing.ClassVar[str] = ...
    EXTRA_NOT_UNKNOWN_SOURCE: typing.ClassVar[str] = ...
    EXTRA_ORIGINATING_URI: typing.ClassVar[str] = ...
    EXTRA_PACKAGES: typing.ClassVar[str] = ...
    EXTRA_PACKAGE_NAME: typing.ClassVar[str] = ...
    EXTRA_PERMISSION_GROUP_NAME: typing.ClassVar[str] = ...
    EXTRA_PHONE_NUMBER: typing.ClassVar[str] = ...
    EXTRA_PROCESS_TEXT: typing.ClassVar[str] = ...
    EXTRA_PROCESS_TEXT_READONLY: typing.ClassVar[str] = ...
    EXTRA_QUICK_VIEW_FEATURES: typing.ClassVar[str] = ...
    EXTRA_QUIET_MODE: typing.ClassVar[str] = ...
    EXTRA_REFERRER: typing.ClassVar[str] = ...
    EXTRA_REFERRER_NAME: typing.ClassVar[str] = ...
    EXTRA_REMOTE_INTENT_TOKEN: typing.ClassVar[str] = ...
    EXTRA_REPLACEMENT_EXTRAS: typing.ClassVar[str] = ...
    EXTRA_REPLACING: typing.ClassVar[str] = ...
    EXTRA_RESTRICTIONS_BUNDLE: typing.ClassVar[str] = ...
    EXTRA_RESTRICTIONS_INTENT: typing.ClassVar[str] = ...
    EXTRA_RESTRICTIONS_LIST: typing.ClassVar[str] = ...
    EXTRA_RESULT_RECEIVER: typing.ClassVar[str] = ...
    EXTRA_RETURN_RESULT: typing.ClassVar[str] = ...
    EXTRA_SHORTCUT_ICON: typing.ClassVar[str] = ...
    EXTRA_SHORTCUT_ICON_RESOURCE: typing.ClassVar[str] = ...
    EXTRA_SHORTCUT_ID: typing.ClassVar[str] = ...
    EXTRA_SHORTCUT_INTENT: typing.ClassVar[str] = ...
    EXTRA_SHORTCUT_NAME: typing.ClassVar[str] = ...
    EXTRA_SHUTDOWN_USERSPACE_ONLY: typing.ClassVar[str] = ...
    EXTRA_SPLIT_NAME: typing.ClassVar[str] = ...
    EXTRA_START_TIME: typing.ClassVar[str] = ...
    EXTRA_STREAM: typing.ClassVar[str] = ...
    EXTRA_SUBJECT: typing.ClassVar[str] = ...
    EXTRA_SUSPENDED_PACKAGE_EXTRAS: typing.ClassVar[str] = ...
    EXTRA_TEMPLATE: typing.ClassVar[str] = ...
    EXTRA_TEXT: typing.ClassVar[str] = ...
    EXTRA_TIME: typing.ClassVar[str] = ...
    EXTRA_TIMEZONE: typing.ClassVar[str] = ...
    EXTRA_TITLE: typing.ClassVar[str] = ...
    EXTRA_UID: typing.ClassVar[str] = ...
    EXTRA_USER: typing.ClassVar[str] = ...
    EXTRA_USER_INITIATED: typing.ClassVar[str] = ...
    EXTRA_USE_STYLUS_MODE: typing.ClassVar[str] = ...
    FILL_IN_ACTION: typing.ClassVar[int] = ...
    FILL_IN_CATEGORIES: typing.ClassVar[int] = ...
    FILL_IN_CLIP_DATA: typing.ClassVar[int] = ...
    FILL_IN_COMPONENT: typing.ClassVar[int] = ...
    FILL_IN_DATA: typing.ClassVar[int] = ...
    FILL_IN_IDENTIFIER: typing.ClassVar[int] = ...
    FILL_IN_PACKAGE: typing.ClassVar[int] = ...
    FILL_IN_SELECTOR: typing.ClassVar[int] = ...
    FILL_IN_SOURCE_BOUNDS: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_BROUGHT_TO_FRONT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_CLEAR_TASK: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_CLEAR_TOP: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_CLEAR_WHEN_TASK_RESET: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_FORWARD_RESULT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_LAUNCHED_FROM_HISTORY: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_LAUNCH_ADJACENT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_MATCH_EXTERNAL: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_MULTIPLE_TASK: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_NEW_DOCUMENT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_NEW_TASK: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_NO_ANIMATION: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_NO_HISTORY: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_NO_USER_ACTION: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_PREVIOUS_IS_TOP: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_REORDER_TO_FRONT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_REQUIRE_DEFAULT: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_REQUIRE_NON_BROWSER: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_RESET_TASK_IF_NEEDED: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_RETAIN_IN_RECENTS: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_SINGLE_TOP: typing.ClassVar[int] = ...
    FLAG_ACTIVITY_TASK_ON_HOME: typing.ClassVar[int] = ...
    FLAG_DEBUG_LOG_RESOLUTION: typing.ClassVar[int] = ...
    FLAG_DIRECT_BOOT_AUTO: typing.ClassVar[int] = ...
    FLAG_EXCLUDE_STOPPED_PACKAGES: typing.ClassVar[int] = ...
    FLAG_FROM_BACKGROUND: typing.ClassVar[int] = ...
    FLAG_GRANT_PERSISTABLE_URI_PERMISSION: typing.ClassVar[int] = ...
    FLAG_GRANT_PREFIX_URI_PERMISSION: typing.ClassVar[int] = ...
    FLAG_GRANT_READ_URI_PERMISSION: typing.ClassVar[int] = ...
    FLAG_GRANT_WRITE_URI_PERMISSION: typing.ClassVar[int] = ...
    FLAG_INCLUDE_STOPPED_PACKAGES: typing.ClassVar[int] = ...
    FLAG_RECEIVER_FOREGROUND: typing.ClassVar[int] = ...
    FLAG_RECEIVER_NO_ABORT: typing.ClassVar[int] = ...
    FLAG_RECEIVER_REGISTERED_ONLY: typing.ClassVar[int] = ...
    FLAG_RECEIVER_REPLACE_PENDING: typing.ClassVar[int] = ...
    FLAG_RECEIVER_VISIBLE_TO_INSTANT_APPS: typing.ClassVar[int] = ...
    METADATA_DOCK_HOME: typing.ClassVar[str] = ...
    URI_ALLOW_UNSAFE: typing.ClassVar[int] = ...
    URI_ANDROID_APP_SCHEME: typing.ClassVar[int] = ...
    URI_INTENT_SCHEME: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, o: Intent, /) -> None: ...
    @typing.overload
    def __init__(self, action: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, packageContext: Context, cls: typing.Type[java.lang.Object], /) -> None: ...
    @typing.overload
    def __init__(self, action: str | java.lang.String, uri: android.net.Uri, /) -> None: ...
    @typing.overload
    def __init__(self, action: str | java.lang.String, uri: android.net.Uri, packageContext: Context, cls: typing.Type[java.lang.Object], /) -> None: ...
    def addCategory(self, category: str | java.lang.String, /) -> Intent: ...
    def addFlags(self, flags: int | java.jint | java.lang.Integer, /) -> Intent: ...
    def clone(self) -> java.lang.Object: ...
    def cloneFilter(self) -> Intent: ...
    @typing.overload
    @staticmethod
    def createChooser(target: Intent, title: java.lang.CharSequence, /) -> Intent: ...
    @typing.overload
    @staticmethod
    def createChooser(target: Intent, title: java.lang.CharSequence, sender: IntentSender, /) -> Intent: ...
    def describeContents(self) -> int: ...
    def fillIn(self, other: Intent, flags: int | java.jint | java.lang.Integer, /) -> int: ...
    def filterEquals(self, other: Intent, /) -> bool: ...
    def filterHashCode(self) -> int: ...
    def getAction(self) -> str | None: ...
    def getBooleanArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJBoolean | None: ...
    def getBooleanExtra(self, name: str | java.lang.String, defaultValue: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getBundleExtra(self, name: str | java.lang.String, /) -> android.os.Bundle | None: ...
    def getByteArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJByte | None: ...
    def getByteExtra(self, name: str | java.lang.String, defaultValue: int | java.jbyte | java.lang.Byte, /) -> int: ...
    def getCategories(self) -> java.util.Set[java.lang.String]: ...
    def getCharArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJChar | None: ...
    def getCharExtra(self, name: str | java.lang.String, defaultValue: str | java.jchar | java.lang.Character, /) -> str: ...
    def getCharSequenceArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.CharSequence] | None: ...
    def getCharSequenceArrayListExtra(self, name: str | java.lang.String, /) -> java.util.ArrayList[java.lang.CharSequence] | None: ...
    def getCharSequenceExtra(self, name: str | java.lang.String, /) -> java.lang.CharSequence | None: ...
    def getClipData(self) -> ClipData | None: ...
    def getComponent(self) -> ComponentName | None: ...
    def getData(self) -> android.net.Uri | None: ...
    def getDataString(self) -> str | None: ...
    def getDoubleArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJDouble | None: ...
    def getDoubleExtra(self, name: str | java.lang.String, defaultValue: float | java.jdouble | java.lang.Double, /) -> float: ...
    def getExtras(self) -> android.os.Bundle | None: ...
    def getFlags(self) -> int: ...
    def getFloatArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJFloat | None: ...
    def getFloatExtra(self, name: str | java.lang.String, defaultValue: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getIdentifier(self) -> str | None: ...
    def getIntArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJInt | None: ...
    def getIntExtra(self, name: str | java.lang.String, defaultValue: int | java.jint | java.lang.Integer, /) -> int: ...
    def getIntegerArrayListExtra(self, name: str | java.lang.String, /) -> java.util.ArrayList[java.lang.Integer] | None: ...
    @staticmethod
    def getIntent(uri: str | java.lang.String, /) -> Intent: ...
    @staticmethod
    def getIntentOld(uri: str | java.lang.String, /) -> Intent: ...
    def getLongArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJLong | None: ...
    def getLongExtra(self, name: str | java.lang.String, defaultValue: int | java.jlong | java.lang.Long, /) -> int: ...
    def getPackage(self) -> str | None: ...
    _getParcelableArrayExtra_1__T = typing.TypeVar('_getParcelableArrayExtra_1__T')  # <T>
    @typing.overload
    def getParcelableArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArray[android.os.Parcelable] | None: ...
    @typing.overload
    def getParcelableArrayExtra(self, name: str | java.lang.String, clazz: typing.Type[_getParcelableArrayExtra_1__T], /) -> java.chaquopy.JavaArray[_getParcelableArrayExtra_1__T] | None: ...
    _getParcelableArrayListExtra_1__T = typing.TypeVar('_getParcelableArrayListExtra_1__T')  # <T>
    @typing.overload
    def getParcelableArrayListExtra(self, name: str | java.lang.String, /) -> java.util.ArrayList[java.lang.Object] | None: ...
    @typing.overload
    def getParcelableArrayListExtra(self, name: str | java.lang.String, clazz: typing.Type[_getParcelableArrayListExtra_1__T], /) -> java.util.ArrayList[_getParcelableArrayListExtra_1__T] | None: ...
    _getParcelableExtra_1__T = typing.TypeVar('_getParcelableExtra_1__T')  # <T>
    @typing.overload
    def getParcelableExtra(self, name: str | java.lang.String, /) -> java.lang.Object | None: ...
    @typing.overload
    def getParcelableExtra(self, name: str | java.lang.String, clazz: typing.Type[_getParcelableExtra_1__T], /) -> _getParcelableExtra_1__T | None: ...
    def getScheme(self) -> str | None: ...
    def getSelector(self) -> Intent | None: ...
    _getSerializableExtra_1__T = typing.TypeVar('_getSerializableExtra_1__T')  # <T>
    @typing.overload
    def getSerializableExtra(self, name: str | java.lang.String, /) -> java.io.Serializable | None: ...
    @typing.overload
    def getSerializableExtra(self, name: str | java.lang.String, clazz: typing.Type[_getSerializableExtra_1__T], /) -> _getSerializableExtra_1__T | None: ...
    def getShortArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArrayJShort | None: ...
    def getShortExtra(self, name: str | java.lang.String, defaultValue: int | java.jshort | java.lang.Short, /) -> int: ...
    def getSourceBounds(self) -> android.graphics.Rect | None: ...
    def getStringArrayExtra(self, name: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String] | None: ...
    def getStringArrayListExtra(self, name: str | java.lang.String, /) -> java.util.ArrayList[java.lang.String] | None: ...
    def getStringExtra(self, name: str | java.lang.String, /) -> str | None: ...
    def getType(self) -> str | None: ...
    def hasCategory(self, category: str | java.lang.String, /) -> bool: ...
    def hasExtra(self, name: str | java.lang.String, /) -> bool: ...
    def hasFileDescriptors(self) -> bool: ...
    def isMismatchingFilter(self) -> bool: ...
    @staticmethod
    def makeMainActivity(mainActivity: ComponentName, /) -> Intent: ...
    @staticmethod
    def makeMainSelectorActivity(selectorAction: str | java.lang.String, selectorCategory: str | java.lang.String, /) -> Intent: ...
    @staticmethod
    def makeRestartActivityTask(mainActivity: ComponentName, /) -> Intent: ...
    @staticmethod
    def normalizeMimeType(type: str | java.lang.String, /) -> str | None: ...
    @staticmethod
    def parseIntent(resources: android.content.res.Resources, parser: org.xmlpull.v1.XmlPullParser, attrs: android.util.AttributeSet, /) -> Intent: ...
    @staticmethod
    def parseUri(uri: str | java.lang.String, flags: int | java.jint | java.lang.Integer, /) -> Intent: ...
    def putCharSequenceArrayListExtra(self, name: str | java.lang.String, value: java.util.ArrayList[java.lang.CharSequence], /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: int | java.jbyte | java.lang.Byte, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: str | java.jchar | java.lang.Character, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: float | java.jdouble | java.lang.Double, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: float | java.jfloat | java.lang.Float, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: int | java.jint | java.lang.Integer, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: int | java.jlong | java.lang.Long, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: android.os.Bundle, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: android.os.Parcelable, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.io.Serializable, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.lang.CharSequence, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: str | java.lang.String, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: int | java.jshort | java.lang.Short, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: bool | java.jboolean | java.lang.Boolean, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJByte, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJChar, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJDouble, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJFloat, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJInt, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJLong, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArray[android.os.Parcelable], /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArray[java.lang.CharSequence], /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArray[java.lang.String], /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJShort, /) -> Intent: ...
    @typing.overload
    def putExtra(self, name: str | java.lang.String, value: java.chaquopy.JavaArrayJBoolean, /) -> Intent: ...
    @typing.overload
    def putExtras(self, src: Intent, /) -> Intent: ...
    @typing.overload
    def putExtras(self, extras: android.os.Bundle, /) -> Intent: ...
    def putIntegerArrayListExtra(self, name: str | java.lang.String, value: java.util.ArrayList[java.lang.Integer], /) -> Intent: ...
    def putParcelableArrayListExtra(self, name: str | java.lang.String, value: java.util.ArrayList[android.os.Parcelable], /) -> Intent: ...
    def putStringArrayListExtra(self, name: str | java.lang.String, value: java.util.ArrayList[java.lang.String], /) -> Intent: ...
    def readFromParcel(self, in_: android.os.Parcel, /) -> None: ...
    def removeCategory(self, category: str | java.lang.String, /) -> None: ...
    def removeExtra(self, name: str | java.lang.String, /) -> None: ...
    def removeFlags(self, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def removeLaunchSecurityProtection(self) -> None: ...
    @typing.overload
    def replaceExtras(self, src: Intent, /) -> Intent: ...
    @typing.overload
    def replaceExtras(self, extras: android.os.Bundle, /) -> Intent: ...
    def resolveActivity(self, pm: android.content.pm.PackageManager, /) -> ComponentName: ...
    def resolveActivityInfo(self, pm: android.content.pm.PackageManager, flags: int | java.jint | java.lang.Integer, /) -> android.content.pm.ActivityInfo: ...
    @typing.overload
    def resolveType(self, resolver: ContentResolver, /) -> str | None: ...
    @typing.overload
    def resolveType(self, context: Context, /) -> str | None: ...
    def resolveTypeIfNeeded(self, resolver: ContentResolver, /) -> str | None: ...
    def setAction(self, action: str | java.lang.String, /) -> Intent: ...
    def setClass(self, packageContext: Context, cls: typing.Type[java.lang.Object], /) -> Intent: ...
    @typing.overload
    def setClassName(self, packageContext: Context, className: str | java.lang.String, /) -> Intent: ...
    @typing.overload
    def setClassName(self, packageName: str | java.lang.String, className: str | java.lang.String, /) -> Intent: ...
    def setClipData(self, clip: ClipData, /) -> None: ...
    def setComponent(self, component: ComponentName, /) -> Intent: ...
    def setData(self, data: android.net.Uri, /) -> Intent: ...
    def setDataAndNormalize(self, data: android.net.Uri, /) -> Intent: ...
    def setDataAndType(self, data: android.net.Uri, type: str | java.lang.String, /) -> Intent: ...
    def setDataAndTypeAndNormalize(self, data: android.net.Uri, type: str | java.lang.String, /) -> Intent: ...
    def setExtrasClassLoader(self, loader: java.lang.ClassLoader, /) -> None: ...
    def setFlags(self, flags: int | java.jint | java.lang.Integer, /) -> Intent: ...
    def setIdentifier(self, identifier: str | java.lang.String, /) -> Intent: ...
    def setPackage(self, packageName: str | java.lang.String, /) -> Intent: ...
    def setSelector(self, selector: Intent, /) -> None: ...
    def setSourceBounds(self, r: android.graphics.Rect, /) -> None: ...
    def setType(self, type: str | java.lang.String, /) -> Intent: ...
    def setTypeAndNormalize(self, type: str | java.lang.String, /) -> Intent: ...
    def toString(self) -> str: ...
    def toURI(self) -> str: ...
    def toUri(self, flags: int | java.jint | java.lang.Integer, /) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class ShortcutIconResource(android.os.Parcelable):
        CREATOR: typing.ClassVar[android.os.Parcelable.Creator[Intent.ShortcutIconResource]] = ...
        packageName: str = ...
        resourceName: str = ...
        def __init__(self) -> None: ...
        def describeContents(self) -> int: ...
        @staticmethod
        def fromContext(context: Context, resourceId: int | java.jint | java.lang.Integer, /) -> Intent.ShortcutIconResource: ...
        def toString(self) -> str: ...
        def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class FilterComparison(java.lang.Object):
        def __init__(self, intent: Intent, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getIntent(self) -> Intent: ...
        def hashCode(self) -> int: ...

class IntentFilter(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[IntentFilter]] = ...
    MATCH_ADJUSTMENT_MASK: typing.ClassVar[int] = ...
    MATCH_ADJUSTMENT_NORMAL: typing.ClassVar[int] = ...
    MATCH_CATEGORY_EMPTY: typing.ClassVar[int] = ...
    MATCH_CATEGORY_HOST: typing.ClassVar[int] = ...
    MATCH_CATEGORY_MASK: typing.ClassVar[int] = ...
    MATCH_CATEGORY_PATH: typing.ClassVar[int] = ...
    MATCH_CATEGORY_PORT: typing.ClassVar[int] = ...
    MATCH_CATEGORY_SCHEME: typing.ClassVar[int] = ...
    MATCH_CATEGORY_SCHEME_SPECIFIC_PART: typing.ClassVar[int] = ...
    MATCH_CATEGORY_TYPE: typing.ClassVar[int] = ...
    NO_MATCH_ACTION: typing.ClassVar[int] = ...
    NO_MATCH_CATEGORY: typing.ClassVar[int] = ...
    NO_MATCH_DATA: typing.ClassVar[int] = ...
    NO_MATCH_TYPE: typing.ClassVar[int] = ...
    SYSTEM_HIGH_PRIORITY: typing.ClassVar[int] = ...
    SYSTEM_LOW_PRIORITY: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, o: IntentFilter, /) -> None: ...
    @typing.overload
    def __init__(self, action: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, action: str | java.lang.String, dataType: str | java.lang.String, /) -> None: ...
    def actionsIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def addAction(self, action: str | java.lang.String, /) -> None: ...
    def addCategory(self, category: str | java.lang.String, /) -> None: ...
    def addDataAuthority(self, host: str | java.lang.String, port: str | java.lang.String, /) -> None: ...
    def addDataPath(self, path: str | java.lang.String, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def addDataScheme(self, scheme: str | java.lang.String, /) -> None: ...
    def addDataSchemeSpecificPart(self, ssp: str | java.lang.String, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def addDataType(self, type: str | java.lang.String, /) -> None: ...
    def addUriRelativeFilterGroup(self, group: UriRelativeFilterGroup, /) -> None: ...
    def asPredicate(self) -> java.util.function.Predicate[Intent]: ...
    def asPredicateWithTypeResolution(self, resolver: ContentResolver, /) -> java.util.function.Predicate[Intent]: ...
    def authoritiesIterator(self) -> java.util.Iterator[IntentFilter.AuthorityEntry]: ...
    def categoriesIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def clearUriRelativeFilterGroups(self) -> None: ...
    def countActions(self) -> int: ...
    def countCategories(self) -> int: ...
    def countDataAuthorities(self) -> int: ...
    def countDataPaths(self) -> int: ...
    def countDataSchemeSpecificParts(self) -> int: ...
    def countDataSchemes(self) -> int: ...
    def countDataTypes(self) -> int: ...
    def countUriRelativeFilterGroups(self) -> int: ...
    @staticmethod
    def create(action: str | java.lang.String, dataType: str | java.lang.String, /) -> IntentFilter: ...
    def describeContents(self) -> int: ...
    def dump(self, du: android.util.Printer, prefix: str | java.lang.String, /) -> None: ...
    def getAction(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getCategory(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getDataAuthority(self, index: int | java.jint | java.lang.Integer, /) -> IntentFilter.AuthorityEntry: ...
    def getDataPath(self, index: int | java.jint | java.lang.Integer, /) -> android.os.PatternMatcher: ...
    def getDataScheme(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getDataSchemeSpecificPart(self, index: int | java.jint | java.lang.Integer, /) -> android.os.PatternMatcher: ...
    def getDataType(self, index: int | java.jint | java.lang.Integer, /) -> str: ...
    def getPriority(self) -> int: ...
    def getUriRelativeFilterGroup(self, index: int | java.jint | java.lang.Integer, /) -> UriRelativeFilterGroup: ...
    def hasAction(self, action: str | java.lang.String, /) -> bool: ...
    def hasCategory(self, category: str | java.lang.String, /) -> bool: ...
    def hasDataAuthority(self, data: android.net.Uri, /) -> bool: ...
    def hasDataPath(self, data: str | java.lang.String, /) -> bool: ...
    def hasDataScheme(self, scheme: str | java.lang.String, /) -> bool: ...
    def hasDataSchemeSpecificPart(self, data: str | java.lang.String, /) -> bool: ...
    def hasDataType(self, type: str | java.lang.String, /) -> bool: ...
    @typing.overload
    def match(self, resolver: ContentResolver, intent: Intent, resolve: bool | java.jboolean | java.lang.Boolean, logTag: str | java.lang.String, /) -> int: ...
    @typing.overload
    def match(self, action: str | java.lang.String, type: str | java.lang.String, scheme: str | java.lang.String, data: android.net.Uri, categories: java.util.Set[java.lang.String], logTag: str | java.lang.String, /) -> int: ...
    def matchAction(self, action: str | java.lang.String, /) -> bool: ...
    def matchCategories(self, categories: java.util.Set[java.lang.String], /) -> str | None: ...
    def matchData(self, type: str | java.lang.String, scheme: str | java.lang.String, data: android.net.Uri, /) -> int: ...
    def matchDataAuthority(self, data: android.net.Uri, /) -> int: ...
    def pathsIterator(self) -> java.util.Iterator[android.os.PatternMatcher]: ...
    def readFromXml(self, parser: org.xmlpull.v1.XmlPullParser, /) -> None: ...
    def schemeSpecificPartsIterator(self) -> java.util.Iterator[android.os.PatternMatcher]: ...
    def schemesIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def setPriority(self, priority: int | java.jint | java.lang.Integer, /) -> None: ...
    def typesIterator(self) -> java.util.Iterator[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def writeToXml(self, serializer: org.xmlpull.v1.XmlSerializer, /) -> None: ...

    class MalformedMimeTypeException(android.util.AndroidException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

    class AuthorityEntry(java.lang.Object):
        def __init__(self, host: str | java.lang.String, port: str | java.lang.String, /) -> None: ...
        def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
        def getHost(self) -> str: ...
        def getPort(self) -> int: ...
        def match(self, data: android.net.Uri, /) -> int: ...

class IntentSender(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[IntentSender]] = ...
    def describeContents(self) -> int: ...
    def equals(self, otherObj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCreatorPackage(self) -> str: ...
    def getCreatorUid(self) -> int: ...
    def getCreatorUserHandle(self) -> android.os.UserHandle: ...
    def getTargetPackage(self) -> str: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def readIntentSenderOrNullFromParcel(in_: android.os.Parcel, /) -> IntentSender: ...
    @typing.overload
    def sendIntent(self, context: Context, code: int | java.jint | java.lang.Integer, intent: Intent, onFinished: IntentSender.OnFinished, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def sendIntent(self, context: Context, code: int | java.jint | java.lang.Integer, intent: Intent, onFinished: IntentSender.OnFinished, handler: android.os.Handler, requiredPermission: str | java.lang.String, /) -> None: ...
    @typing.overload
    def sendIntent(self, context: Context, code: int | java.jint | java.lang.Integer, intent: Intent, requiredPermission: str | java.lang.String, options: android.os.Bundle, executor: java.util.concurrent.Executor, onFinished: IntentSender.OnFinished, /) -> None: ...
    def toString(self) -> str: ...
    @staticmethod
    def writeIntentSenderOrNullToParcel(sender: IntentSender, out: android.os.Parcel, /) -> None: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class SendIntentException(android.util.AndroidException):
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, cause: java.lang.Exception, /) -> None: ...
        @typing.overload
        def __init__(self, name: str | java.lang.String, /) -> None: ...

    class OnFinished(java.lang.Object):
        def onSendFinished(self, arg1: IntentSender, arg2: Intent, arg3: int | java.jint | java.lang.Integer, arg4: str | java.lang.String, arg5: android.os.Bundle, /) -> None: ...

_Loader__D = typing.TypeVar('_Loader__D')  # <D>

_Loader__OnLoadCompleteListener__D = typing.TypeVar('_Loader__OnLoadCompleteListener__D')  # <D>

_Loader__OnLoadCanceledListener__D = typing.TypeVar('_Loader__OnLoadCanceledListener__D')  # <D>
class Loader(java.lang.Object, typing.Generic[_Loader__D]):
    def __init__(self, context: Context, /) -> None: ...
    def abandon(self) -> None: ...
    def cancelLoad(self) -> bool: ...
    def commitContentChanged(self) -> None: ...
    def dataToString(self, data: _Loader__D, /) -> str: ...
    def deliverCancellation(self) -> None: ...
    def deliverResult(self, data: _Loader__D, /) -> None: ...
    def dump(self, prefix: str | java.lang.String, fd: java.io.FileDescriptor, writer: java.io.PrintWriter, args: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def forceLoad(self) -> None: ...
    def getContext(self) -> Context: ...
    def getId(self) -> int: ...
    def isAbandoned(self) -> bool: ...
    def isReset(self) -> bool: ...
    def isStarted(self) -> bool: ...
    def onAbandon(self) -> None: ...
    def onCancelLoad(self) -> bool: ...
    def onContentChanged(self) -> None: ...
    def onForceLoad(self) -> None: ...
    def onReset(self) -> None: ...
    def onStartLoading(self) -> None: ...
    def onStopLoading(self) -> None: ...
    def registerListener(self, id: int | java.jint | java.lang.Integer, listener: Loader.OnLoadCompleteListener[_Loader__D], /) -> None: ...
    def registerOnLoadCanceledListener(self, listener: Loader.OnLoadCanceledListener[_Loader__D], /) -> None: ...
    def reset(self) -> None: ...
    def rollbackContentChanged(self) -> None: ...
    def startLoading(self) -> None: ...
    def stopLoading(self) -> None: ...
    def takeContentChanged(self) -> bool: ...
    def toString(self) -> str: ...
    def unregisterListener(self, listener: Loader.OnLoadCompleteListener[_Loader__D], /) -> None: ...
    def unregisterOnLoadCanceledListener(self, listener: Loader.OnLoadCanceledListener[_Loader__D], /) -> None: ...
    class OnLoadCompleteListener(java.lang.Object, typing.Generic[_Loader__OnLoadCompleteListener__D]):
        def onLoadComplete(self, arg1: Loader[_Loader__OnLoadCompleteListener__D], arg2: _Loader__OnLoadCompleteListener__D, /) -> None: ...
    class OnLoadCanceledListener(java.lang.Object, typing.Generic[_Loader__OnLoadCanceledListener__D]):
        def onLoadCanceled(self, arg1: Loader[_Loader__OnLoadCanceledListener__D], /) -> None: ...

    class ForceLoadContentObserver(android.database.ContentObserver):
        def __init__(self, this_0: Loader, /) -> None: ...
        def deliverSelfNotifications(self) -> bool: ...
        def onChange(self, selfChange: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class LocusId(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[LocusId]] = ...
    def __init__(self, id: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getId(self) -> str: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class MutableContextWrapper(ContextWrapper):
    def __init__(self, base: Context, /) -> None: ...
    def setBaseContext(self, base: Context, /) -> None: ...

class OperationApplicationException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, numSuccessfulYieldPoints: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, cause: java.lang.Throwable, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, numSuccessfulYieldPoints: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, cause: java.lang.Throwable, /) -> None: ...
    def getNumSuccessfulYieldPoints(self) -> int: ...

class PeriodicSync(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PeriodicSync]] = ...
    account: android.accounts.Account = ...
    authority: str = ...
    extras: android.os.Bundle = ...
    period: int = ...
    def __init__(self, account: android.accounts.Account, authority: str | java.lang.String, extras: android.os.Bundle, periodInSeconds: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class QuickViewConstants(java.lang.Object):
    FEATURE_DELETE: typing.ClassVar[str] = ...
    FEATURE_DOWNLOAD: typing.ClassVar[str] = ...
    FEATURE_EDIT: typing.ClassVar[str] = ...
    FEATURE_PRINT: typing.ClassVar[str] = ...
    FEATURE_SEND: typing.ClassVar[str] = ...
    FEATURE_VIEW: typing.ClassVar[str] = ...

class ReceiverCallNotAllowedException(android.util.AndroidRuntimeException):
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class RestrictionEntry(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[RestrictionEntry]] = ...
    TYPE_BOOLEAN: typing.ClassVar[int] = ...
    TYPE_BUNDLE: typing.ClassVar[int] = ...
    TYPE_BUNDLE_ARRAY: typing.ClassVar[int] = ...
    TYPE_CHOICE: typing.ClassVar[int] = ...
    TYPE_INTEGER: typing.ClassVar[int] = ...
    TYPE_MULTI_SELECT: typing.ClassVar[int] = ...
    TYPE_NULL: typing.ClassVar[int] = ...
    TYPE_STRING: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, type: int | java.jint | java.lang.Integer, key: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, key: str | java.lang.String, selectedInt: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, key: str | java.lang.String, selectedString: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, key: str | java.lang.String, selectedState: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def __init__(self, key: str | java.lang.String, selectedStrings: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @staticmethod
    def createBundleArrayEntry(key: str | java.lang.String, restrictionEntries: java.chaquopy.JavaArray[RestrictionEntry], /) -> RestrictionEntry: ...
    @staticmethod
    def createBundleEntry(key: str | java.lang.String, restrictionEntries: java.chaquopy.JavaArray[RestrictionEntry], /) -> RestrictionEntry: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAllSelectedStrings(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getChoiceEntries(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getChoiceValues(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def getDescription(self) -> str | None: ...
    def getIntValue(self) -> int: ...
    def getKey(self) -> str: ...
    def getRestrictions(self) -> java.chaquopy.JavaArray[RestrictionEntry]: ...
    def getSelectedState(self) -> bool: ...
    def getSelectedString(self) -> str | None: ...
    def getTitle(self) -> str | None: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def setAllSelectedStrings(self, allSelectedStrings: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def setChoiceEntries(self, choiceEntries: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def setChoiceEntries(self, context: Context, stringArrayResId: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def setChoiceValues(self, choiceValues: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    @typing.overload
    def setChoiceValues(self, context: Context, stringArrayResId: int | java.jint | java.lang.Integer, /) -> None: ...
    def setDescription(self, description: str | java.lang.String, /) -> None: ...
    def setIntValue(self, value: int | java.jint | java.lang.Integer, /) -> None: ...
    def setRestrictions(self, restrictions: java.chaquopy.JavaArray[RestrictionEntry], /) -> None: ...
    def setSelectedState(self, state: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSelectedString(self, selectedString: str | java.lang.String, /) -> None: ...
    def setTitle(self, title: str | java.lang.String, /) -> None: ...
    def setType(self, type: int | java.jint | java.lang.Integer, /) -> None: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class RestrictionsManager(java.lang.Object):
    ACTION_PERMISSION_RESPONSE_RECEIVED: typing.ClassVar[str] = ...
    ACTION_REQUEST_LOCAL_APPROVAL: typing.ClassVar[str] = ...
    ACTION_REQUEST_PERMISSION: typing.ClassVar[str] = ...
    EXTRA_PACKAGE_NAME: typing.ClassVar[str] = ...
    EXTRA_REQUEST_BUNDLE: typing.ClassVar[str] = ...
    EXTRA_REQUEST_ID: typing.ClassVar[str] = ...
    EXTRA_REQUEST_TYPE: typing.ClassVar[str] = ...
    EXTRA_RESPONSE_BUNDLE: typing.ClassVar[str] = ...
    META_DATA_APP_RESTRICTIONS: typing.ClassVar[str] = ...
    REQUEST_KEY_APPROVE_LABEL: typing.ClassVar[str] = ...
    REQUEST_KEY_DATA: typing.ClassVar[str] = ...
    REQUEST_KEY_DENY_LABEL: typing.ClassVar[str] = ...
    REQUEST_KEY_ICON: typing.ClassVar[str] = ...
    REQUEST_KEY_ID: typing.ClassVar[str] = ...
    REQUEST_KEY_MESSAGE: typing.ClassVar[str] = ...
    REQUEST_KEY_NEW_REQUEST: typing.ClassVar[str] = ...
    REQUEST_KEY_TITLE: typing.ClassVar[str] = ...
    REQUEST_TYPE_APPROVAL: typing.ClassVar[str] = ...
    RESPONSE_KEY_ERROR_CODE: typing.ClassVar[str] = ...
    RESPONSE_KEY_MESSAGE: typing.ClassVar[str] = ...
    RESPONSE_KEY_RESPONSE_TIMESTAMP: typing.ClassVar[str] = ...
    RESPONSE_KEY_RESULT: typing.ClassVar[str] = ...
    RESULT_APPROVED: typing.ClassVar[int] = ...
    RESULT_DENIED: typing.ClassVar[int] = ...
    RESULT_ERROR: typing.ClassVar[int] = ...
    RESULT_ERROR_BAD_REQUEST: typing.ClassVar[int] = ...
    RESULT_ERROR_INTERNAL: typing.ClassVar[int] = ...
    RESULT_ERROR_NETWORK: typing.ClassVar[int] = ...
    RESULT_NO_RESPONSE: typing.ClassVar[int] = ...
    RESULT_UNKNOWN_REQUEST: typing.ClassVar[int] = ...
    @staticmethod
    def convertRestrictionsToBundle(entries: java.util.List[RestrictionEntry], /) -> android.os.Bundle: ...
    def createLocalApprovalIntent(self) -> Intent: ...
    def getApplicationRestrictions(self) -> android.os.Bundle | None: ...
    def getApplicationRestrictionsPerAdmin(self) -> java.util.List[android.os.Bundle]: ...
    def getManifestRestrictions(self, packageName: str | java.lang.String, /) -> java.util.List[RestrictionEntry] | None: ...
    def hasRestrictionsProvider(self) -> bool: ...
    def notifyPermissionResponse(self, packageName: str | java.lang.String, response: android.os.PersistableBundle, /) -> None: ...
    def requestPermission(self, requestType: str | java.lang.String, requestId: str | java.lang.String, request: android.os.PersistableBundle, /) -> None: ...

class SearchRecentSuggestionsProvider(ContentProvider):
    DATABASE_MODE_2LINES: typing.ClassVar[int] = ...
    DATABASE_MODE_QUERIES: typing.ClassVar[int] = ...
    def __init__(self) -> None: ...
    def delete(self, uri: android.net.Uri, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...
    def getType(self, uri: android.net.Uri, /) -> str: ...
    def insert(self, uri: android.net.Uri, values: ContentValues, /) -> android.net.Uri: ...
    def onCreate(self) -> bool: ...
    def query(self, uri: android.net.Uri, projection: java.chaquopy.JavaArray[java.lang.String], selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], sortOrder: str | java.lang.String, /) -> android.database.Cursor: ...
    def setupSuggestions(self, authority: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def update(self, uri: android.net.Uri, values: ContentValues, selection: str | java.lang.String, selectionArgs: java.chaquopy.JavaArray[java.lang.String], /) -> int: ...

class ServiceConnection(java.lang.Object):
    def onBindingDied(self, name: ComponentName, /) -> None: ...
    def onNullBinding(self, name: ComponentName, /) -> None: ...
    def onServiceConnected(self, arg1: ComponentName, arg2: android.os.IBinder, /) -> None: ...
    def onServiceDisconnected(self, arg1: ComponentName, /) -> None: ...

class SharedPreferences(java.lang.Object):
    def contains(self, arg1: str | java.lang.String, /) -> bool: ...
    def edit(self) -> SharedPreferences.Editor: ...
    def getAll(self) -> java.util.Map[java.lang.String, java.lang.Object]: ...
    def getBoolean(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> bool: ...
    def getFloat(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> float: ...
    def getInt(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> int: ...
    def getLong(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> int: ...
    def getString(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> str | None: ...
    def getStringSet(self, arg1: str | java.lang.String, arg2: java.util.Set[java.lang.String], /) -> java.util.Set[java.lang.String] | None: ...
    def registerOnSharedPreferenceChangeListener(self, arg1: SharedPreferences.OnSharedPreferenceChangeListener, /) -> None: ...
    def unregisterOnSharedPreferenceChangeListener(self, arg1: SharedPreferences.OnSharedPreferenceChangeListener, /) -> None: ...

    class OnSharedPreferenceChangeListener(java.lang.Object):
        def onSharedPreferenceChanged(self, arg1: SharedPreferences, arg2: str | java.lang.String, /) -> None: ...

    class Editor(java.lang.Object):
        def apply(self) -> None: ...
        def clear(self) -> SharedPreferences.Editor: ...
        def commit(self) -> bool: ...
        def putBoolean(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> SharedPreferences.Editor: ...
        def putFloat(self, arg1: str | java.lang.String, arg2: float | java.jfloat | java.lang.Float, /) -> SharedPreferences.Editor: ...
        def putInt(self, arg1: str | java.lang.String, arg2: int | java.jint | java.lang.Integer, /) -> SharedPreferences.Editor: ...
        def putLong(self, arg1: str | java.lang.String, arg2: int | java.jlong | java.lang.Long, /) -> SharedPreferences.Editor: ...
        def putString(self, arg1: str | java.lang.String, arg2: str | java.lang.String, /) -> SharedPreferences.Editor: ...
        def putStringSet(self, arg1: str | java.lang.String, arg2: java.util.Set[java.lang.String], /) -> SharedPreferences.Editor: ...
        def remove(self, arg1: str | java.lang.String, /) -> SharedPreferences.Editor: ...

class SyncAdapterType(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncAdapterType]] = ...
    accountType: str = ...
    authority: str = ...
    isKey: bool = ...
    @typing.overload
    def __init__(self, source: android.os.Parcel, /) -> None: ...
    @typing.overload
    def __init__(self, authority: str | java.lang.String, accountType: str | java.lang.String, userVisible: bool | java.jboolean | java.lang.Boolean, supportsUploading: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def allowParallelSyncs(self) -> bool: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getSettingsActivity(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def isAlwaysSyncable(self) -> bool: ...
    def isUserVisible(self) -> bool: ...
    @staticmethod
    def newKey(authority: str | java.lang.String, accountType: str | java.lang.String, /) -> SyncAdapterType: ...
    def supportsUploading(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncContext(java.lang.Object):
    def getSyncContextBinder(self) -> android.os.IBinder: ...
    def onFinished(self, result: SyncResult, /) -> None: ...

class SyncInfo(android.os.Parcelable):
    account: android.accounts.Account = ...
    authority: str = ...
    startTime: int = ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncRequest]] = ...
    def describeContents(self) -> int: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self) -> None: ...
        def build(self) -> SyncRequest: ...
        def setDisallowMetered(self, disallow: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setExpedited(self, expedited: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setExtras(self, bundle: android.os.Bundle, /) -> SyncRequest.Builder: ...
        def setIgnoreBackoff(self, ignoreBackoff: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setIgnoreSettings(self, ignoreSettings: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setManual(self, isManual: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setNoRetry(self, noRetry: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setRequiresCharging(self, requiresCharging: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setScheduleAsExpeditedJob(self, scheduleAsExpeditedJob: bool | java.jboolean | java.lang.Boolean, /) -> SyncRequest.Builder: ...
        def setSyncAdapter(self, account: android.accounts.Account, authority: str | java.lang.String, /) -> SyncRequest.Builder: ...
        def syncOnce(self) -> SyncRequest.Builder: ...
        def syncPeriodic(self, pollFrequency: int | java.jlong | java.lang.Long, beforeSeconds: int | java.jlong | java.lang.Long, /) -> SyncRequest.Builder: ...

class SyncResult(android.os.Parcelable):
    ALREADY_IN_PROGRESS: typing.ClassVar[SyncResult] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncResult]] = ...
    databaseError: bool = ...
    delayUntil: int = ...
    fullSyncRequested: bool = ...
    moreRecordsToGet: bool = ...
    partialSyncUnavailable: bool = ...
    stats: SyncStats = ...
    syncAlreadyInProgress: bool = ...
    tooManyDeletions: bool = ...
    tooManyRetries: bool = ...
    def __init__(self) -> None: ...
    def clear(self) -> None: ...
    def describeContents(self) -> int: ...
    def hasError(self) -> bool: ...
    def hasHardError(self) -> bool: ...
    def hasSoftError(self) -> bool: ...
    def madeSomeProgress(self) -> bool: ...
    def toDebugString(self) -> str: ...
    def toString(self) -> str: ...
    def writeToParcel(self, parcel: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncStats(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SyncStats]] = ...
    numAuthExceptions: int = ...
    numConflictDetectedExceptions: int = ...
    numDeletes: int = ...
    numEntries: int = ...
    numInserts: int = ...
    numIoExceptions: int = ...
    numParseExceptions: int = ...
    numSkippedEntries: int = ...
    numUpdates: int = ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, in_: android.os.Parcel, /) -> None: ...
    def clear(self) -> None: ...
    def describeContents(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SyncStatusObserver(java.lang.Object):
    def onStatusChanged(self, arg1: int | java.jint | java.lang.Integer, /) -> None: ...

class UriMatcher(java.lang.Object):
    NO_MATCH: typing.ClassVar[int] = ...
    def __init__(self, code: int | java.jint | java.lang.Integer, /) -> None: ...
    def addURI(self, authority: str | java.lang.String, path: str | java.lang.String, code: int | java.jint | java.lang.Integer, /) -> None: ...
    def match(self, uri: android.net.Uri, /) -> int: ...

class UriPermission(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[UriPermission]] = ...
    INVALID_TIME: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getPersistedTime(self) -> int: ...
    def getUri(self) -> android.net.Uri: ...
    def isReadPermission(self) -> bool: ...
    def isWritePermission(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class UriRelativeFilter(java.lang.Object):
    FRAGMENT: typing.ClassVar[int] = ...
    PATH: typing.ClassVar[int] = ...
    QUERY: typing.ClassVar[int] = ...
    def __init__(self, uriPart: int | java.jint | java.lang.Integer, patternType: int | java.jint | java.lang.Integer, filter: str | java.lang.String, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getFilter(self) -> str: ...
    def getPatternType(self) -> int: ...
    def getUriPart(self) -> int: ...
    def hashCode(self) -> int: ...
    def matchData(self, data: android.net.Uri, /) -> bool: ...
    def toString(self) -> str: ...

class UriRelativeFilterGroup(java.lang.Object):
    ACTION_ALLOW: typing.ClassVar[int] = ...
    ACTION_BLOCK: typing.ClassVar[int] = ...
    def __init__(self, action: int | java.jint | java.lang.Integer, /) -> None: ...
    def addUriRelativeFilter(self, uriRelativeFilter: UriRelativeFilter, /) -> None: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAction(self) -> int: ...
    def getUriRelativeFilters(self) -> java.util.Collection[UriRelativeFilter]: ...
    def hashCode(self) -> int: ...
    def matchData(self, data: android.net.Uri, /) -> bool: ...
    def toString(self) -> str: ...
